# coding: utf-8

"""
    Xero Payroll NZ

    This is the Xero Payroll API for orgs in the NZ region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class EmployeeLeave(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "leave_id": "str",
        "leave_type_id": "str",
        "description": "str",
        "start_date": "date",
        "end_date": "date",
        "periods": "list[LeavePeriod]",
        "updated_date_utc": "datetime",
    }

    attribute_map = {
        "leave_id": "leaveID",
        "leave_type_id": "leaveTypeID",
        "description": "description",
        "start_date": "startDate",
        "end_date": "endDate",
        "periods": "periods",
        "updated_date_utc": "updatedDateUTC",
    }

    def __init__(
        self,
        leave_id=None,
        leave_type_id=None,
        description=None,
        start_date=None,
        end_date=None,
        periods=None,
        updated_date_utc=None,
    ):  # noqa: E501
        """EmployeeLeave - a model defined in OpenAPI"""  # noqa: E501

        self._leave_id = None
        self._leave_type_id = None
        self._description = None
        self._start_date = None
        self._end_date = None
        self._periods = None
        self._updated_date_utc = None
        self.discriminator = None

        if leave_id is not None:
            self.leave_id = leave_id
        self.leave_type_id = leave_type_id
        self.description = description
        self.start_date = start_date
        self.end_date = end_date
        if periods is not None:
            self.periods = periods
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc

    @property
    def leave_id(self):
        """Gets the leave_id of this EmployeeLeave.  # noqa: E501

        The Xero identifier for LeaveType  # noqa: E501

        :return: The leave_id of this EmployeeLeave.  # noqa: E501
        :rtype: str
        """
        return self._leave_id

    @leave_id.setter
    def leave_id(self, leave_id):
        """Sets the leave_id of this EmployeeLeave.

        The Xero identifier for LeaveType  # noqa: E501

        :param leave_id: The leave_id of this EmployeeLeave.  # noqa: E501
        :type: str
        """

        self._leave_id = leave_id

    @property
    def leave_type_id(self):
        """Gets the leave_type_id of this EmployeeLeave.  # noqa: E501

        The Xero identifier for LeaveType  # noqa: E501

        :return: The leave_type_id of this EmployeeLeave.  # noqa: E501
        :rtype: str
        """
        return self._leave_type_id

    @leave_type_id.setter
    def leave_type_id(self, leave_type_id):
        """Sets the leave_type_id of this EmployeeLeave.

        The Xero identifier for LeaveType  # noqa: E501

        :param leave_type_id: The leave_type_id of this EmployeeLeave.  # noqa: E501
        :type: str
        """
        if leave_type_id is None:
            raise ValueError(
                "Invalid value for `leave_type_id`, must not be `None`"
            )  # noqa: E501

        self._leave_type_id = leave_type_id

    @property
    def description(self):
        """Gets the description of this EmployeeLeave.  # noqa: E501

        The description of the leave  (max length = 50)  # noqa: E501

        :return: The description of this EmployeeLeave.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this EmployeeLeave.

        The description of the leave  (max length = 50)  # noqa: E501

        :param description: The description of this EmployeeLeave.  # noqa: E501
        :type: str
        """
        if description is None:
            raise ValueError(
                "Invalid value for `description`, must not be `None`"
            )  # noqa: E501

        self._description = description

    @property
    def start_date(self):
        """Gets the start_date of this EmployeeLeave.  # noqa: E501

        Start date of the leave (YYYY-MM-DD)  # noqa: E501

        :return: The start_date of this EmployeeLeave.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this EmployeeLeave.

        Start date of the leave (YYYY-MM-DD)  # noqa: E501

        :param start_date: The start_date of this EmployeeLeave.  # noqa: E501
        :type: date
        """
        if start_date is None:
            raise ValueError(
                "Invalid value for `start_date`, must not be `None`"
            )  # noqa: E501

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this EmployeeLeave.  # noqa: E501

        End date of the leave (YYYY-MM-DD)  # noqa: E501

        :return: The end_date of this EmployeeLeave.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this EmployeeLeave.

        End date of the leave (YYYY-MM-DD)  # noqa: E501

        :param end_date: The end_date of this EmployeeLeave.  # noqa: E501
        :type: date
        """
        if end_date is None:
            raise ValueError(
                "Invalid value for `end_date`, must not be `None`"
            )  # noqa: E501

        self._end_date = end_date

    @property
    def periods(self):
        """Gets the periods of this EmployeeLeave.  # noqa: E501

        The leave period information. The StartDate, EndDate and NumberOfUnits needs to be specified when you do not want to calculate NumberOfUnits automatically. Using incorrect period StartDate and EndDate will result in automatic computation of the NumberOfUnits.  # noqa: E501

        :return: The periods of this EmployeeLeave.  # noqa: E501
        :rtype: list[LeavePeriod]
        """
        return self._periods

    @periods.setter
    def periods(self, periods):
        """Sets the periods of this EmployeeLeave.

        The leave period information. The StartDate, EndDate and NumberOfUnits needs to be specified when you do not want to calculate NumberOfUnits automatically. Using incorrect period StartDate and EndDate will result in automatic computation of the NumberOfUnits.  # noqa: E501

        :param periods: The periods of this EmployeeLeave.  # noqa: E501
        :type: list[LeavePeriod]
        """

        self._periods = periods

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this EmployeeLeave.  # noqa: E501

        UTC timestamp of last update to the leave type note  # noqa: E501

        :return: The updated_date_utc of this EmployeeLeave.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this EmployeeLeave.

        UTC timestamp of last update to the leave type note  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this EmployeeLeave.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Settings(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "accounts": "list[Account]",
        "tracking_categories": "SettingsTrackingCategories",
        "days_in_payroll_year": "int",
    }

    attribute_map = {
        "accounts": "Accounts",
        "tracking_categories": "TrackingCategories",
        "days_in_payroll_year": "DaysInPayrollYear",
    }

    def __init__(
        self, accounts=None, tracking_categories=None, days_in_payroll_year=None
    ):  # noqa: E501
        """Settings - a model defined in OpenAPI"""  # noqa: E501

        self._accounts = None
        self._tracking_categories = None
        self._days_in_payroll_year = None
        self.discriminator = None

        if accounts is not None:
            self.accounts = accounts
        if tracking_categories is not None:
            self.tracking_categories = tracking_categories
        if days_in_payroll_year is not None:
            self.days_in_payroll_year = days_in_payroll_year

    @property
    def accounts(self):
        """Gets the accounts of this Settings.  # noqa: E501

        Payroll Account details for SuperExpense, SuperLiabilty, WagesExpense, PAYGLiability & WagesPayable.  # noqa: E501

        :return: The accounts of this Settings.  # noqa: E501
        :rtype: list[Account]
        """
        return self._accounts

    @accounts.setter
    def accounts(self, accounts):
        """Sets the accounts of this Settings.

        Payroll Account details for SuperExpense, SuperLiabilty, WagesExpense, PAYGLiability & WagesPayable.  # noqa: E501

        :param accounts: The accounts of this Settings.  # noqa: E501
        :type: list[Account]
        """

        self._accounts = accounts

    @property
    def tracking_categories(self):
        """Gets the tracking_categories of this Settings.  # noqa: E501


        :return: The tracking_categories of this Settings.  # noqa: E501
        :rtype: SettingsTrackingCategories
        """
        return self._tracking_categories

    @tracking_categories.setter
    def tracking_categories(self, tracking_categories):
        """Sets the tracking_categories of this Settings.


        :param tracking_categories: The tracking_categories of this Settings.  # noqa: E501
        :type: SettingsTrackingCategories
        """

        self._tracking_categories = tracking_categories

    @property
    def days_in_payroll_year(self):
        """Gets the days_in_payroll_year of this Settings.  # noqa: E501

        Number of days in the Payroll year  # noqa: E501

        :return: The days_in_payroll_year of this Settings.  # noqa: E501
        :rtype: int
        """
        return self._days_in_payroll_year

    @days_in_payroll_year.setter
    def days_in_payroll_year(self, days_in_payroll_year):
        """Sets the days_in_payroll_year of this Settings.

        Number of days in the Payroll year  # noqa: E501

        :param days_in_payroll_year: The days_in_payroll_year of this Settings.  # noqa: E501
        :type: int
        """

        self._days_in_payroll_year = days_in_payroll_year



# coding: utf-8

"""
    Xero Projects API

    This is the Xero Projects API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""

"""
    OpenAPI spec version: 2.10.4
"""

import importlib
import re  # noqa: F401

from xero_python import exceptions
from xero_python.api_client import ApiClient, ModelFinder

try:
    from .exception_handler import translate_status_exception
except ImportError:
    translate_status_exception = exceptions.translate_status_exception


class empty:
    """ empty object to mark optional parameter not set """


class ProjectApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    base_url = "https://api.xero.com/projects.xro/2.0"
    models_module = importlib.import_module("xero_python.project.models")

    def __init__(self, api_client=None, base_url=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.base_url = base_url or self.base_url

    def get_resource_url(self, resource_path):
        """
        Combine API base url with resource specific path
        :param str resource_path: API endpoint specific path
        :return: str full resource path
        """
        return self.base_url + resource_path

    def get_model_finder(self):
        return ModelFinder(self.models_module)

    def create_project(
        self,
        xero_tenant_id,
        project_create_or_update,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Create one or more new projects  # noqa: E501
        OAuth2 scope: projects.create
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param ProjectCreateOrUpdate project_create_or_update: Create a new project with ProjectCreateOrUpdate object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Project
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `create_project`"
            )
        # verify the required parameter 'project_create_or_update' is set
        if project_create_or_update is None:
            raise ValueError(
                "Missing the required parameter `project_create_or_update` "
                "when calling `create_project`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = project_create_or_update
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Projects")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Project",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "create_project")

    def create_time_entry(
        self,
        xero_tenant_id,
        project_id,
        time_entry_create_or_update,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Creates a time entry for a specific project  # noqa: E501
        OAuth2 scope: projects, projects.read
        Allows you to create a specific task  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str project_id: You can specify an individual project by appending the projectId to the endpoint (required)
        :param TimeEntryCreateOrUpdate time_entry_create_or_update: The time entry object you are creating (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: TimeEntry
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `create_time_entry`"
            )
        # verify the required parameter 'project_id' is set
        if project_id is None:
            raise ValueError(
                "Missing the required parameter `project_id` "
                "when calling `create_time_entry`"
            )
        # verify the required parameter 'time_entry_create_or_update' is set
        if time_entry_create_or_update is None:
            raise ValueError(
                "Missing the required parameter `time_entry_create_or_update` "
                "when calling `create_time_entry`"
            )

        collection_formats = {}
        path_params = {
            "projectId": project_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = time_entry_create_or_update
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Projects/{projectId}/Time")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="TimeEntry",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "create_time_entry")

    def delete_time_entry(
        self,
        xero_tenant_id,
        project_id,
        time_entry_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Deletes a time entry for a specific project  # noqa: E501
        OAuth2 scope: projects, projects.read
        Allows you to delete a specific time entry  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str project_id: You can specify an individual project by appending the projectId to the endpoint (required)
        :param str time_entry_id: You can specify an individual task by appending the id to the endpoint (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: None
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `delete_time_entry`"
            )
        # verify the required parameter 'project_id' is set
        if project_id is None:
            raise ValueError(
                "Missing the required parameter `project_id` "
                "when calling `delete_time_entry`"
            )
        # verify the required parameter 'time_entry_id' is set
        if time_entry_id is None:
            raise ValueError(
                "Missing the required parameter `time_entry_id` "
                "when calling `delete_time_entry`"
            )

        collection_formats = {}
        path_params = {
            "projectId": project_id,
            "timeEntryId": time_entry_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Projects/{projectId}/Time/{timeEntryId}")

        try:
            return self.api_client.call_api(
                url,
                "DELETE",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type=None,
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "delete_time_entry")

    def get_project(
        self,
        xero_tenant_id,
        project_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves a single project  # noqa: E501
        OAuth2 scope: projects, projects.read
        Allows you to retrieve a specific project using the projectId  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str project_id: You can specify an individual project by appending the projectId to the endpoint (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Project
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_project`"
            )
        # verify the required parameter 'project_id' is set
        if project_id is None:
            raise ValueError(
                "Missing the required parameter `project_id` "
                "when calling `get_project`"
            )

        collection_formats = {}
        path_params = {
            "projectId": project_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Projects/{projectId}")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Project",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_project")

    def get_project_users(
        self,
        xero_tenant_id,
        page=empty,
        page_size=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves a list of all project users  # noqa: E501
        OAuth2 scope: projects.read
        Allows you to retrieve the users on a projects.  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param int page: set to 1 by default. The requested number of the page in paged response - Must be a number greater than 0.
        :param int page_size: Optional, it is set to 50 by default. The number of items to return per page in a paged response - Must be a number between 1 and 500.
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: ProjectUsers
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_project_users`"
            )

        if page_size is not empty and page_size > 500:
            raise ValueError(
                "Invalid value for parameter `page_size` "
                "when calling `get_project_users`, must be a value "
                "less than or equal to "
                "`500`"
            )
        if page_size is not empty and page_size < 1:
            raise ValueError(
                "Invalid value for parameter `page_size` "
                "when calling `get_project_users`, must be a value "
                "greater than or equal to "
                "`1`"
            )
        collection_formats = {}
        path_params = {}

        query_params = []

        if page is not empty:
            query_params.append(("page", page))

        if page_size is not empty:
            query_params.append(("pageSize", page_size))

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/ProjectsUsers")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="ProjectUsers",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_project_users")

    def get_projects(
        self,
        xero_tenant_id,
        project_ids=empty,
        contact_id=empty,
        states=empty,
        page=empty,
        page_size=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves all projects  # noqa: E501
        OAuth2 scope: projects, projects.read
        Allows you to retrieve, create and update projects.  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param list[str] project_ids: Search for all projects that match a comma separated list of projectIds
        :param str contact_id: Filter for projects for a specific contact
        :param str states: Filter for projects in a particular state (INPROGRESS or CLOSED)
        :param int page: set to 1 by default. The requested number of the page in paged response - Must be a number greater than 0.
        :param int page_size: Optional, it is set to 50 by default. The number of items to return per page in a paged response - Must be a number between 1 and 500.
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Projects
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_projects`"
            )

        if page_size is not empty and page_size > 500:
            raise ValueError(
                "Invalid value for parameter `page_size` "
                "when calling `get_projects`, must be a value "
                "less than or equal to "
                "`500`"
            )
        if page_size is not empty and page_size < 1:
            raise ValueError(
                "Invalid value for parameter `page_size` "
                "when calling `get_projects`, must be a value "
                "greater than or equal to "
                "`1`"
            )
        collection_formats = {
            "projectIds": "multi",
        }
        path_params = {}

        query_params = []

        if project_ids is not empty:
            query_params.append(("projectIds", project_ids))

        if contact_id is not empty:
            query_params.append(("contactID", contact_id))

        if states is not empty:
            query_params.append(("states", states))

        if page is not empty:
            query_params.append(("page", page))

        if page_size is not empty:
            query_params.append(("pageSize", page_size))

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Projects")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Projects",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_projects")

    def get_task(
        self,
        xero_tenant_id,
        project_id,
        task_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves a single project task  # noqa: E501
        OAuth2 scope: projects, projects.read
        Allows you to retrieve a specific project  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str project_id: You can specify an individual project by appending the projectId to the endpoint (required)
        :param str task_id: You can specify an individual task by appending the taskId to the endpoint, i.e. GET https://.../tasks/{taskID} (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Task
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_task`"
            )
        # verify the required parameter 'project_id' is set
        if project_id is None:
            raise ValueError(
                "Missing the required parameter `project_id` " "when calling `get_task`"
            )
        # verify the required parameter 'task_id' is set
        if task_id is None:
            raise ValueError(
                "Missing the required parameter `task_id` " "when calling `get_task`"
            )

        collection_formats = {}
        path_params = {
            "projectId": project_id,
            "taskId": task_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Projects/{projectId}/Tasks/{taskId}")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Task",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_task")

    def get_tasks(
        self,
        xero_tenant_id,
        project_id,
        page=empty,
        page_size=empty,
        task_ids=empty,
        charge_type=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves all project tasks  # noqa: E501
        OAuth2 scope: projects, projects.read
        Allows you to retrieve a specific project  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str project_id: You can specify an individual project by appending the projectId to the endpoint (required)
        :param int page: Set to 1 by default. The requested number of the page in paged response - Must be a number greater than 0.
        :param int page_size: Optional, it is set to 50 by default. The number of items to return per page in a paged response - Must be a number between 1 and 500.
        :param str task_ids: taskIdsSearch for all tasks that match a comma separated list of taskIds, i.e. GET https://.../tasks?taskIds={taskID},{taskID}
        :param ChargeType charge_type:
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Tasks
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_tasks`"
            )
        # verify the required parameter 'project_id' is set
        if project_id is None:
            raise ValueError(
                "Missing the required parameter `project_id` "
                "when calling `get_tasks`"
            )

        collection_formats = {}
        path_params = {
            "projectId": project_id,
        }

        query_params = []

        if page is not empty:
            query_params.append(("page", page))

        if page_size is not empty:
            query_params.append(("pageSize", page_size))

        if task_ids is not empty:
            query_params.append(("taskIds", task_ids))

        if charge_type is not empty:
            query_params.append(("chargeType", charge_type))

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Projects/{projectId}/Tasks")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Tasks",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_tasks")

    def get_time_entries(
        self,
        xero_tenant_id,
        project_id,
        user_id=empty,
        task_id=empty,
        invoice_id=empty,
        contact_id=empty,
        page=empty,
        page_size=empty,
        states=empty,
        is_chargeable=empty,
        date_after_utc=empty,
        date_before_utc=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves all time entries associated with a specific project  # noqa: E501
        OAuth2 scope: projects, projects.read
        Allows you to retrieve the time entries associated with a specific project  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str project_id: Identifier of the project, that the task (which the time entry is logged against) belongs to. (required)
        :param str user_id: The xero user identifier of the person who logged time.
        :param str task_id: Identifier of the task that time entry is logged against.
        :param str invoice_id: Finds all time entries for this invoice.
        :param str contact_id: Finds all time entries for this contact identifier.
        :param int page: Set to 1 by default. The requested number of the page in paged response - Must be a number greater than 0.
        :param int page_size: Optional, it is set to 50 by default. The number of items to return per page in a paged response - Must be a number between 1 and 500.
        :param list[str] states: Comma-separated list of states to find. Will find all time entries that are in the status of whatever is specified.
        :param bool is_chargeable: Finds all time entries which relate to tasks with the charge type `TIME` or `FIXED`.
        :param datetime date_after_utc: ISO 8601 UTC date. Finds all time entries on or after this date filtered on the `dateUtc` field.
        :param datetime date_before_utc: ISO 8601 UTC date. Finds all time entries on or before this date filtered on the `dateUtc` field.
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: TimeEntries
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_time_entries`"
            )
        # verify the required parameter 'project_id' is set
        if project_id is None:
            raise ValueError(
                "Missing the required parameter `project_id` "
                "when calling `get_time_entries`"
            )

        collection_formats = {
            "states": "multi",
        }
        path_params = {
            "projectId": project_id,
        }

        query_params = []

        if user_id is not empty:
            query_params.append(("userId", user_id))

        if task_id is not empty:
            query_params.append(("taskId", task_id))

        if invoice_id is not empty:
            query_params.append(("invoiceId", invoice_id))

        if contact_id is not empty:
            query_params.append(("contactId", contact_id))

        if page is not empty:
            query_params.append(("page", page))

        if page_size is not empty:
            query_params.append(("pageSize", page_size))

        if states is not empty:
            query_params.append(("states", states))

        if is_chargeable is not empty:
            query_params.append(("isChargeable", is_chargeable))

        if date_after_utc is not empty:
            query_params.append(("dateAfterUtc", date_after_utc))

        if date_before_utc is not empty:
            query_params.append(("dateBeforeUtc", date_before_utc))

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Projects/{projectId}/Time")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="TimeEntries",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_time_entries")

    def get_time_entry(
        self,
        xero_tenant_id,
        project_id,
        time_entry_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves a single time entry for a specific project  # noqa: E501
        OAuth2 scope: projects, projects.read
        Allows you to get a single time entry in a project  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str project_id: You can specify an individual project by appending the projectId to the endpoint (required)
        :param str time_entry_id: You can specify an individual time entry by appending the id to the endpoint (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: TimeEntry
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_time_entry`"
            )
        # verify the required parameter 'project_id' is set
        if project_id is None:
            raise ValueError(
                "Missing the required parameter `project_id` "
                "when calling `get_time_entry`"
            )
        # verify the required parameter 'time_entry_id' is set
        if time_entry_id is None:
            raise ValueError(
                "Missing the required parameter `time_entry_id` "
                "when calling `get_time_entry`"
            )

        collection_formats = {}
        path_params = {
            "projectId": project_id,
            "timeEntryId": time_entry_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Projects/{projectId}/Time/{timeEntryId}")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="TimeEntry",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_time_entry")

    def patch_project(
        self,
        xero_tenant_id,
        project_id,
        project_patch,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """creates a project for the specified contact  # noqa: E501
        OAuth2 scope: projects.create
        Allows you to update a specific projects.  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str project_id: You can specify an individual project by appending the projectId to the endpoint (required)
        :param ProjectPatch project_patch: Update the status of an existing Project (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: None
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `patch_project`"
            )
        # verify the required parameter 'project_id' is set
        if project_id is None:
            raise ValueError(
                "Missing the required parameter `project_id` "
                "when calling `patch_project`"
            )
        # verify the required parameter 'project_patch' is set
        if project_patch is None:
            raise ValueError(
                "Missing the required parameter `project_patch` "
                "when calling `patch_project`"
            )

        collection_formats = {}
        path_params = {
            "projectId": project_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = project_patch
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Projects/{projectId}")

        try:
            return self.api_client.call_api(
                url,
                "PATCH",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type=None,
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "patch_project")

    def update_project(
        self,
        xero_tenant_id,
        project_id,
        project_create_or_update,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Updates a specific project  # noqa: E501
        OAuth2 scope: projects.create
        Allows you to update a specific projects.  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str project_id: You can specify an individual project by appending the projectId to the endpoint (required)
        :param ProjectCreateOrUpdate project_create_or_update: Request of type ProjectCreateOrUpdate (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: None
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `update_project`"
            )
        # verify the required parameter 'project_id' is set
        if project_id is None:
            raise ValueError(
                "Missing the required parameter `project_id` "
                "when calling `update_project`"
            )
        # verify the required parameter 'project_create_or_update' is set
        if project_create_or_update is None:
            raise ValueError(
                "Missing the required parameter `project_create_or_update` "
                "when calling `update_project`"
            )

        collection_formats = {}
        path_params = {
            "projectId": project_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = project_create_or_update
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Projects/{projectId}")

        try:
            return self.api_client.call_api(
                url,
                "PUT",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type=None,
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "update_project")

    def update_time_entry(
        self,
        xero_tenant_id,
        project_id,
        time_entry_id,
        time_entry_create_or_update,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Updates a time entry for a specific project  # noqa: E501
        OAuth2 scope: projects, projects.read
        Allows you to update time entry in a project  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str project_id: You can specify an individual project by appending the projectId to the endpoint (required)
        :param str time_entry_id: You can specify an individual time entry by appending the id to the endpoint (required)
        :param TimeEntryCreateOrUpdate time_entry_create_or_update: The time entry object you are updating (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: None
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `update_time_entry`"
            )
        # verify the required parameter 'project_id' is set
        if project_id is None:
            raise ValueError(
                "Missing the required parameter `project_id` "
                "when calling `update_time_entry`"
            )
        # verify the required parameter 'time_entry_id' is set
        if time_entry_id is None:
            raise ValueError(
                "Missing the required parameter `time_entry_id` "
                "when calling `update_time_entry`"
            )
        # verify the required parameter 'time_entry_create_or_update' is set
        if time_entry_create_or_update is None:
            raise ValueError(
                "Missing the required parameter `time_entry_create_or_update` "
                "when calling `update_time_entry`"
            )

        collection_formats = {}
        path_params = {
            "projectId": project_id,
            "timeEntryId": time_entry_id,
        }

        query_params = []

        header_params = {
            "Xero-Tenant-Id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = time_entry_create_or_update
        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Projects/{projectId}/Time/{timeEntryId}")

        try:
            return self.api_client.call_api(
                url,
                "PUT",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type=None,
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "update_time_entry")



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class ReimbursementLines(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"reimbursement_lines": "list[ReimbursementLine]"}

    attribute_map = {"reimbursement_lines": "ReimbursementLines"}

    def __init__(self, reimbursement_lines=None):  # noqa: E501
        """ReimbursementLines - a model defined in OpenAPI"""  # noqa: E501

        self._reimbursement_lines = None
        self.discriminator = None

        if reimbursement_lines is not None:
            self.reimbursement_lines = reimbursement_lines

    @property
    def reimbursement_lines(self):
        """Gets the reimbursement_lines of this ReimbursementLines.  # noqa: E501


        :return: The reimbursement_lines of this ReimbursementLines.  # noqa: E501
        :rtype: list[ReimbursementLine]
        """
        return self._reimbursement_lines

    @reimbursement_lines.setter
    def reimbursement_lines(self, reimbursement_lines):
        """Sets the reimbursement_lines of this ReimbursementLines.


        :param reimbursement_lines: The reimbursement_lines of this ReimbursementLines.  # noqa: E501
        :type: list[ReimbursementLine]
        """

        self._reimbursement_lines = reimbursement_lines



# coding: utf-8

"""
    Xero Payroll NZ

    This is the Xero Payroll API for orgs in the NZ region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class EmployeeLeaveBalance(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "name": "str",
        "leave_type_id": "str",
        "balance": "float",
        "type_of_units": "str",
    }

    attribute_map = {
        "name": "name",
        "leave_type_id": "leaveTypeID",
        "balance": "balance",
        "type_of_units": "typeOfUnits",
    }

    def __init__(
        self, name=None, leave_type_id=None, balance=None, type_of_units=None
    ):  # noqa: E501
        """EmployeeLeaveBalance - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._leave_type_id = None
        self._balance = None
        self._type_of_units = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if leave_type_id is not None:
            self.leave_type_id = leave_type_id
        if balance is not None:
            self.balance = balance
        if type_of_units is not None:
            self.type_of_units = type_of_units

    @property
    def name(self):
        """Gets the name of this EmployeeLeaveBalance.  # noqa: E501

        Name of the leave type.  # noqa: E501

        :return: The name of this EmployeeLeaveBalance.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this EmployeeLeaveBalance.

        Name of the leave type.  # noqa: E501

        :param name: The name of this EmployeeLeaveBalance.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def leave_type_id(self):
        """Gets the leave_type_id of this EmployeeLeaveBalance.  # noqa: E501

        The Xero identifier for leave type  # noqa: E501

        :return: The leave_type_id of this EmployeeLeaveBalance.  # noqa: E501
        :rtype: str
        """
        return self._leave_type_id

    @leave_type_id.setter
    def leave_type_id(self, leave_type_id):
        """Sets the leave_type_id of this EmployeeLeaveBalance.

        The Xero identifier for leave type  # noqa: E501

        :param leave_type_id: The leave_type_id of this EmployeeLeaveBalance.  # noqa: E501
        :type: str
        """

        self._leave_type_id = leave_type_id

    @property
    def balance(self):
        """Gets the balance of this EmployeeLeaveBalance.  # noqa: E501

        The employees current balance for the corresponding leave type.  # noqa: E501

        :return: The balance of this EmployeeLeaveBalance.  # noqa: E501
        :rtype: float
        """
        return self._balance

    @balance.setter
    def balance(self, balance):
        """Sets the balance of this EmployeeLeaveBalance.

        The employees current balance for the corresponding leave type.  # noqa: E501

        :param balance: The balance of this EmployeeLeaveBalance.  # noqa: E501
        :type: float
        """

        self._balance = balance

    @property
    def type_of_units(self):
        """Gets the type_of_units of this EmployeeLeaveBalance.  # noqa: E501

        The type of the units of the leave.  # noqa: E501

        :return: The type_of_units of this EmployeeLeaveBalance.  # noqa: E501
        :rtype: str
        """
        return self._type_of_units

    @type_of_units.setter
    def type_of_units(self, type_of_units):
        """Sets the type_of_units of this EmployeeLeaveBalance.

        The type of the units of the leave.  # noqa: E501

        :param type_of_units: The type_of_units of this EmployeeLeaveBalance.  # noqa: E501
        :type: str
        """

        self._type_of_units = type_of_units



# -*- coding: utf-8 -*-
import json
from decimal import Decimal
from string import capwords

from . import ApiException, OAuth2Error
from ..utils import getvalue


def translate_status_exception(error, api_instance, api_method):
    """Translate HTTPStatusException into proper Xero API status error
    :param error: HTTPStatusException
    :param api_instance: xero api instance exception occurred to
    :param api_method: xero api instance method name exception occurred to
    :return: HTTPStatusException
    """
    if error.status == 429:
        return RateLimitException(http_resp=error.http_resp)
    if error.status == 404:
        return NotFoundException(http_resp=error.http_resp)
    if error.status == 400:
        return BadRequestException(http_resp=error.http_resp)
    return error


class HTTPStatusException(ApiException):
    """Exception for http status != 2xx """


class RateLimitException(HTTPStatusException):
    """Exception if Xero API rate limit reached """

    @property
    def rate_limit(self):
        try:
            return self.headers.get("x-rate-limit-problem")
        except Exception:
            return None

    @property
    def error_message(self):
        return "You've exceeded the per {} rate limit".format(self.rate_limit)


class NotFoundException(HTTPStatusException):
    """Exception if Xero API resource not found"""

    @property
    def error_message(self):
        return "The resource you're looking for cannot be found"


class BadRequestException(HTTPStatusException):
    """Exception if Xero API received bad request"""

    @property
    def error_data(self):
        return json.loads(getattr(self.http_resp, "text", ""), parse_float=Decimal)


class AccountingBadRequestException(BadRequestException):
    """Exception if Xero Accounting API received bad request"""

    @property
    def status(self):
        return getattr(self.error_data, "Message", None) or super().status

    @property
    def reason(self):
        return (
            getvalue(self.error_data, "Elements.0.ValidationErrors.0.Message", None)
            or super().reason
        )


class PayrollUkBadRequestException(BadRequestException):
    """Exception if Xero Accounting API received bad request"""

    @property
    def status(self):
        return getattr(self.error_data, "Message", None) or super().status

    @property
    def reason(self):
        return getvalue(self.error_data, "problem", None) or super().reason


class OAuth2InvalidGrantError(BadRequestException, OAuth2Error):
    """Exception if Xero Identity API received bad oauth2 grant token request"""

    @property
    def reason(self):
        value = getvalue(self.error_data, "error", "")
        if value:
            return capwords(value.replace("_", " "))

        return super().reason



# coding: utf-8

"""
    Xero Assets API

    The Assets API exposes fixed asset related functions of the Xero Accounting application and can be used for a variety of purposes such as creating assets, retrieving asset valuations etc.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Assets(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"pagination": "Pagination", "items": "list[Asset]"}

    attribute_map = {"pagination": "pagination", "items": "items"}

    def __init__(self, pagination=None, items=None):  # noqa: E501
        """Assets - a model defined in OpenAPI"""  # noqa: E501

        self._pagination = None
        self._items = None
        self.discriminator = None

        if pagination is not None:
            self.pagination = pagination
        if items is not None:
            self.items = items

    @property
    def pagination(self):
        """Gets the pagination of this Assets.  # noqa: E501


        :return: The pagination of this Assets.  # noqa: E501
        :rtype: Pagination
        """
        return self._pagination

    @pagination.setter
    def pagination(self, pagination):
        """Sets the pagination of this Assets.


        :param pagination: The pagination of this Assets.  # noqa: E501
        :type: Pagination
        """

        self._pagination = pagination

    @property
    def items(self):
        """Gets the items of this Assets.  # noqa: E501


        :return: The items of this Assets.  # noqa: E501
        :rtype: list[Asset]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this Assets.


        :param items: The items of this Assets.  # noqa: E501
        :type: list[Asset]
        """

        self._items = items



# coding: utf-8

"""
    Xero Payroll NZ

    This is the Xero Payroll API for orgs in the NZ region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Address(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "address_line1": "str",
        "address_line2": "str",
        "city": "str",
        "suburb": "str",
        "post_code": "str",
        "country_name": "str",
    }

    attribute_map = {
        "address_line1": "addressLine1",
        "address_line2": "addressLine2",
        "city": "city",
        "suburb": "suburb",
        "post_code": "postCode",
        "country_name": "countryName",
    }

    def __init__(
        self,
        address_line1=None,
        address_line2=None,
        city=None,
        suburb=None,
        post_code=None,
        country_name=None,
    ):  # noqa: E501
        """Address - a model defined in OpenAPI"""  # noqa: E501

        self._address_line1 = None
        self._address_line2 = None
        self._city = None
        self._suburb = None
        self._post_code = None
        self._country_name = None
        self.discriminator = None

        self.address_line1 = address_line1
        if address_line2 is not None:
            self.address_line2 = address_line2
        self.city = city
        if suburb is not None:
            self.suburb = suburb
        self.post_code = post_code
        if country_name is not None:
            self.country_name = country_name

    @property
    def address_line1(self):
        """Gets the address_line1 of this Address.  # noqa: E501

        Address line 1 for employee home address  # noqa: E501

        :return: The address_line1 of this Address.  # noqa: E501
        :rtype: str
        """
        return self._address_line1

    @address_line1.setter
    def address_line1(self, address_line1):
        """Sets the address_line1 of this Address.

        Address line 1 for employee home address  # noqa: E501

        :param address_line1: The address_line1 of this Address.  # noqa: E501
        :type: str
        """
        if address_line1 is None:
            raise ValueError(
                "Invalid value for `address_line1`, must not be `None`"
            )  # noqa: E501

        self._address_line1 = address_line1

    @property
    def address_line2(self):
        """Gets the address_line2 of this Address.  # noqa: E501

        Address line 2 for employee home address  # noqa: E501

        :return: The address_line2 of this Address.  # noqa: E501
        :rtype: str
        """
        return self._address_line2

    @address_line2.setter
    def address_line2(self, address_line2):
        """Sets the address_line2 of this Address.

        Address line 2 for employee home address  # noqa: E501

        :param address_line2: The address_line2 of this Address.  # noqa: E501
        :type: str
        """

        self._address_line2 = address_line2

    @property
    def city(self):
        """Gets the city of this Address.  # noqa: E501

        Suburb for employee home address  # noqa: E501

        :return: The city of this Address.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this Address.

        Suburb for employee home address  # noqa: E501

        :param city: The city of this Address.  # noqa: E501
        :type: str
        """
        if city is None:
            raise ValueError(
                "Invalid value for `city`, must not be `None`"
            )  # noqa: E501

        self._city = city

    @property
    def suburb(self):
        """Gets the suburb of this Address.  # noqa: E501

        Suburb for employee home address  # noqa: E501

        :return: The suburb of this Address.  # noqa: E501
        :rtype: str
        """
        return self._suburb

    @suburb.setter
    def suburb(self, suburb):
        """Sets the suburb of this Address.

        Suburb for employee home address  # noqa: E501

        :param suburb: The suburb of this Address.  # noqa: E501
        :type: str
        """

        self._suburb = suburb

    @property
    def post_code(self):
        """Gets the post_code of this Address.  # noqa: E501

        PostCode for employee home address  # noqa: E501

        :return: The post_code of this Address.  # noqa: E501
        :rtype: str
        """
        return self._post_code

    @post_code.setter
    def post_code(self, post_code):
        """Sets the post_code of this Address.

        PostCode for employee home address  # noqa: E501

        :param post_code: The post_code of this Address.  # noqa: E501
        :type: str
        """
        if post_code is None:
            raise ValueError(
                "Invalid value for `post_code`, must not be `None`"
            )  # noqa: E501

        self._post_code = post_code

    @property
    def country_name(self):
        """Gets the country_name of this Address.  # noqa: E501

        Country of HomeAddress  # noqa: E501

        :return: The country_name of this Address.  # noqa: E501
        :rtype: str
        """
        return self._country_name

    @country_name.setter
    def country_name(self, country_name):
        """Sets the country_name of this Address.

        Country of HomeAddress  # noqa: E501

        :param country_name: The country_name of this Address.  # noqa: E501
        :type: str
        """

        self._country_name = country_name



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from enum import Enum


class TaxType(Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    allowed enum values
    """

    OUTPUT = "OUTPUT"
    INPUT = "INPUT"
    CAPEXINPUT = "CAPEXINPUT"
    EXEMPTEXPORT = "EXEMPTEXPORT"
    EXEMPTEXPENSES = "EXEMPTEXPENSES"
    EXEMPTCAPITAL = "EXEMPTCAPITAL"
    EXEMPTOUTPUT = "EXEMPTOUTPUT"
    INPUTTAXED = "INPUTTAXED"
    BASEXCLUDED = "BASEXCLUDED"
    GSTONCAPIMPORTS = "GSTONCAPIMPORTS"
    GSTONIMPORTS = "GSTONIMPORTS"
    NONE = "NONE"
    INPUT2 = "INPUT2"
    ZERORATED = "ZERORATED"
    OUTPUT2 = "OUTPUT2"
    CAPEXINPUT2 = "CAPEXINPUT2"
    CAPEXOUTPUT = "CAPEXOUTPUT"
    CAPEXOUTPUT2 = "CAPEXOUTPUT2"
    CAPEXSRINPUT = "CAPEXSRINPUT"
    CAPEXSROUTPUT = "CAPEXSROUTPUT"
    ECACQUISITIONS = "ECACQUISITIONS"
    ECZRINPUT = "ECZRINPUT"
    ECZROUTPUT = "ECZROUTPUT"
    ECZROUTPUTSERVICES = "ECZROUTPUTSERVICES"
    EXEMPTINPUT = "EXEMPTINPUT"
    REVERSECHARGES = "REVERSECHARGES"
    RRINPUT = "RRINPUT"
    RROUTPUT = "RROUTPUT"
    SRINPUT = "SRINPUT"
    SROUTPUT = "SROUTPUT"
    ZERORATEDINPUT = "ZERORATEDINPUT"
    ZERORATEDOUTPUT = "ZERORATEDOUTPUT"
    BLINPUT = "BLINPUT"
    DSOUTPUT = "DSOUTPUT"
    EPINPUT = "EPINPUT"
    ES33OUTPUT = "ES33OUTPUT"
    ESN33OUTPUT = "ESN33OUTPUT"
    IGDSINPUT2 = "IGDSINPUT2"
    IMINPUT2 = "IMINPUT2"
    MEINPUT = "MEINPUT"
    NRINPUT = "NRINPUT"
    OPINPUT = "OPINPUT"
    OSOUTPUT = "OSOUTPUT"
    TXESSINPUT = "TXESSINPUT"
    TXN33INPUT = "TXN33INPUT"
    TXPETINPUT = "TXPETINPUT"
    TXREINPUT = "TXREINPUT"
    INPUT3 = "INPUT3"
    INPUT4 = "INPUT4"
    OUTPUT3 = "OUTPUT3"
    OUTPUT4 = "OUTPUT4"
    SROUTPUT2 = "SROUTPUT2"
    TXCA = "TXCA"
    SRCAS = "SRCAS"
    BLINPUT2 = "BLINPUT2"
    DRCHARGESUPPLY20 = "DRCHARGESUPPLY20"
    DRCHARGE20 = "DRCHARGE20"
    DRCHARGESUPPLY5 = "DRCHARGESUPPLY5"
    DRCHARGE5 = "DRCHARGE5"



# coding: utf-8

# flake8: noqa

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


# import apis into sdk package
from xero_python.payrollau.api.payroll_au_api import PayrollAuApi


# import models into sdk package
from xero_python.payrollau.models.api_exception import APIException
from xero_python.payrollau.models.account import Account
from xero_python.payrollau.models.account_type import AccountType
from xero_python.payrollau.models.allowance_type import AllowanceType
from xero_python.payrollau.models.bank_account import BankAccount
from xero_python.payrollau.models.calendar_type import CalendarType
from xero_python.payrollau.models.deduction_line import DeductionLine
from xero_python.payrollau.models.deduction_type import DeductionType
from xero_python.payrollau.models.deduction_type_calculation_type import (
    DeductionTypeCalculationType,
)
from xero_python.payrollau.models.earnings_line import EarningsLine
from xero_python.payrollau.models.earnings_rate import EarningsRate
from xero_python.payrollau.models.earnings_rate_calculation_type import (
    EarningsRateCalculationType,
)
from xero_python.payrollau.models.earnings_type import EarningsType
from xero_python.payrollau.models.employee import Employee
from xero_python.payrollau.models.employee_status import EmployeeStatus
from xero_python.payrollau.models.employees import Employees
from xero_python.payrollau.models.employment_basis import EmploymentBasis
from xero_python.payrollau.models.employment_termination_payment_type import (
    EmploymentTerminationPaymentType,
)
from xero_python.payrollau.models.entitlement_final_pay_payout_type import (
    EntitlementFinalPayPayoutType,
)
from xero_python.payrollau.models.home_address import HomeAddress
from xero_python.payrollau.models.leave_accrual_line import LeaveAccrualLine
from xero_python.payrollau.models.leave_application import LeaveApplication
from xero_python.payrollau.models.leave_applications import LeaveApplications
from xero_python.payrollau.models.leave_balance import LeaveBalance
from xero_python.payrollau.models.leave_earnings_line import LeaveEarningsLine
from xero_python.payrollau.models.leave_line import LeaveLine
from xero_python.payrollau.models.leave_line_calculation_type import (
    LeaveLineCalculationType,
)
from xero_python.payrollau.models.leave_lines import LeaveLines
from xero_python.payrollau.models.leave_period import LeavePeriod
from xero_python.payrollau.models.leave_period_status import LeavePeriodStatus
from xero_python.payrollau.models.leave_type import LeaveType
from xero_python.payrollau.models.leave_type_contribution_type import (
    LeaveTypeContributionType,
)
from xero_python.payrollau.models.manual_tax_type import ManualTaxType
from xero_python.payrollau.models.opening_balances import OpeningBalances
from xero_python.payrollau.models.pay_item import PayItem
from xero_python.payrollau.models.pay_items import PayItems
from xero_python.payrollau.models.pay_run import PayRun
from xero_python.payrollau.models.pay_run_status import PayRunStatus
from xero_python.payrollau.models.pay_runs import PayRuns
from xero_python.payrollau.models.pay_template import PayTemplate
from xero_python.payrollau.models.payment_frequency_type import PaymentFrequencyType
from xero_python.payrollau.models.payroll_calendar import PayrollCalendar
from xero_python.payrollau.models.payroll_calendars import PayrollCalendars
from xero_python.payrollau.models.payslip import Payslip
from xero_python.payrollau.models.payslip_lines import PayslipLines
from xero_python.payrollau.models.payslip_object import PayslipObject
from xero_python.payrollau.models.payslip_summary import PayslipSummary
from xero_python.payrollau.models.payslips import Payslips
from xero_python.payrollau.models.rate_type import RateType
from xero_python.payrollau.models.reimbursement_line import ReimbursementLine
from xero_python.payrollau.models.reimbursement_lines import ReimbursementLines
from xero_python.payrollau.models.reimbursement_type import ReimbursementType
from xero_python.payrollau.models.residency_status import ResidencyStatus
from xero_python.payrollau.models.settings import Settings
from xero_python.payrollau.models.settings_object import SettingsObject
from xero_python.payrollau.models.settings_tracking_categories import (
    SettingsTrackingCategories,
)
from xero_python.payrollau.models.settings_tracking_categories_employee_groups import (
    SettingsTrackingCategoriesEmployeeGroups,
)
from xero_python.payrollau.models.settings_tracking_categories_timesheet_categories import (
    SettingsTrackingCategoriesTimesheetCategories,
)
from xero_python.payrollau.models.state import State
from xero_python.payrollau.models.super_fund import SuperFund
from xero_python.payrollau.models.super_fund_product import SuperFundProduct
from xero_python.payrollau.models.super_fund_products import SuperFundProducts
from xero_python.payrollau.models.super_fund_type import SuperFundType
from xero_python.payrollau.models.super_funds import SuperFunds
from xero_python.payrollau.models.super_line import SuperLine
from xero_python.payrollau.models.super_membership import SuperMembership
from xero_python.payrollau.models.superannuation_calculation_type import (
    SuperannuationCalculationType,
)
from xero_python.payrollau.models.superannuation_contribution_type import (
    SuperannuationContributionType,
)
from xero_python.payrollau.models.superannuation_line import SuperannuationLine
from xero_python.payrollau.models.tfn_exemption_type import TFNExemptionType
from xero_python.payrollau.models.tax_declaration import TaxDeclaration
from xero_python.payrollau.models.tax_line import TaxLine
from xero_python.payrollau.models.timesheet import Timesheet
from xero_python.payrollau.models.timesheet_line import TimesheetLine
from xero_python.payrollau.models.timesheet_object import TimesheetObject
from xero_python.payrollau.models.timesheet_status import TimesheetStatus
from xero_python.payrollau.models.timesheets import Timesheets
from xero_python.payrollau.models.validation_error import ValidationError



# coding: utf-8

"""
    Xero Assets API

    The Assets API exposes fixed asset related functions of the Xero Accounting application and can be used for a variety of purposes such as creating assets, retrieving asset valuations etc.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class BookDepreciationSetting(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "depreciation_method": "str",
        "averaging_method": "str",
        "depreciation_rate": "float",
        "effective_life_years": "int",
        "depreciation_calculation_method": "str",
        "depreciable_object_id": "str",
        "depreciable_object_type": "str",
        "book_effective_date_of_change_id": "str",
    }

    attribute_map = {
        "depreciation_method": "depreciationMethod",
        "averaging_method": "averagingMethod",
        "depreciation_rate": "depreciationRate",
        "effective_life_years": "effectiveLifeYears",
        "depreciation_calculation_method": "depreciationCalculationMethod",
        "depreciable_object_id": "depreciableObjectId",
        "depreciable_object_type": "depreciableObjectType",
        "book_effective_date_of_change_id": "bookEffectiveDateOfChangeId",
    }

    def __init__(
        self,
        depreciation_method=None,
        averaging_method=None,
        depreciation_rate=None,
        effective_life_years=None,
        depreciation_calculation_method=None,
        depreciable_object_id=None,
        depreciable_object_type=None,
        book_effective_date_of_change_id=None,
    ):  # noqa: E501
        """BookDepreciationSetting - a model defined in OpenAPI"""  # noqa: E501

        self._depreciation_method = None
        self._averaging_method = None
        self._depreciation_rate = None
        self._effective_life_years = None
        self._depreciation_calculation_method = None
        self._depreciable_object_id = None
        self._depreciable_object_type = None
        self._book_effective_date_of_change_id = None
        self.discriminator = None

        if depreciation_method is not None:
            self.depreciation_method = depreciation_method
        if averaging_method is not None:
            self.averaging_method = averaging_method
        if depreciation_rate is not None:
            self.depreciation_rate = depreciation_rate
        if effective_life_years is not None:
            self.effective_life_years = effective_life_years
        if depreciation_calculation_method is not None:
            self.depreciation_calculation_method = depreciation_calculation_method
        if depreciable_object_id is not None:
            self.depreciable_object_id = depreciable_object_id
        if depreciable_object_type is not None:
            self.depreciable_object_type = depreciable_object_type
        if book_effective_date_of_change_id is not None:
            self.book_effective_date_of_change_id = book_effective_date_of_change_id

    @property
    def depreciation_method(self):
        """Gets the depreciation_method of this BookDepreciationSetting.  # noqa: E501

        The method of depreciation applied to this asset. See Depreciation Methods  # noqa: E501

        :return: The depreciation_method of this BookDepreciationSetting.  # noqa: E501
        :rtype: str
        """
        return self._depreciation_method

    @depreciation_method.setter
    def depreciation_method(self, depreciation_method):
        """Sets the depreciation_method of this BookDepreciationSetting.

        The method of depreciation applied to this asset. See Depreciation Methods  # noqa: E501

        :param depreciation_method: The depreciation_method of this BookDepreciationSetting.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "NoDepreciation",
            "StraightLine",
            "DiminishingValue100",
            "DiminishingValue150",
            "DiminishingValue200",
            "FullDepreciation",
            "None",
        ]  # noqa: E501

        if depreciation_method:
            if depreciation_method not in allowed_values:
                raise ValueError(
                    "Invalid value for `depreciation_method` ({0}), must be one of {1}".format(  # noqa: E501
                        depreciation_method, allowed_values
                    )
                )

        self._depreciation_method = depreciation_method

    @property
    def averaging_method(self):
        """Gets the averaging_method of this BookDepreciationSetting.  # noqa: E501

        The method of averaging applied to this asset. See Averaging Methods  # noqa: E501

        :return: The averaging_method of this BookDepreciationSetting.  # noqa: E501
        :rtype: str
        """
        return self._averaging_method

    @averaging_method.setter
    def averaging_method(self, averaging_method):
        """Sets the averaging_method of this BookDepreciationSetting.

        The method of averaging applied to this asset. See Averaging Methods  # noqa: E501

        :param averaging_method: The averaging_method of this BookDepreciationSetting.  # noqa: E501
        :type: str
        """
        allowed_values = ["FullMonth", "ActualDays", "None"]  # noqa: E501

        if averaging_method:
            if averaging_method not in allowed_values:
                raise ValueError(
                    "Invalid value for `averaging_method` ({0}), must be one of {1}".format(  # noqa: E501
                        averaging_method, allowed_values
                    )
                )

        self._averaging_method = averaging_method

    @property
    def depreciation_rate(self):
        """Gets the depreciation_rate of this BookDepreciationSetting.  # noqa: E501

        The rate of depreciation (e.g. 0.05)  # noqa: E501

        :return: The depreciation_rate of this BookDepreciationSetting.  # noqa: E501
        :rtype: float
        """
        return self._depreciation_rate

    @depreciation_rate.setter
    def depreciation_rate(self, depreciation_rate):
        """Sets the depreciation_rate of this BookDepreciationSetting.

        The rate of depreciation (e.g. 0.05)  # noqa: E501

        :param depreciation_rate: The depreciation_rate of this BookDepreciationSetting.  # noqa: E501
        :type: float
        """

        self._depreciation_rate = depreciation_rate

    @property
    def effective_life_years(self):
        """Gets the effective_life_years of this BookDepreciationSetting.  # noqa: E501

        Effective life of the asset in years (e.g. 5)  # noqa: E501

        :return: The effective_life_years of this BookDepreciationSetting.  # noqa: E501
        :rtype: int
        """
        return self._effective_life_years

    @effective_life_years.setter
    def effective_life_years(self, effective_life_years):
        """Sets the effective_life_years of this BookDepreciationSetting.

        Effective life of the asset in years (e.g. 5)  # noqa: E501

        :param effective_life_years: The effective_life_years of this BookDepreciationSetting.  # noqa: E501
        :type: int
        """

        self._effective_life_years = effective_life_years

    @property
    def depreciation_calculation_method(self):
        """Gets the depreciation_calculation_method of this BookDepreciationSetting.  # noqa: E501

        See Depreciation Calculation Methods  # noqa: E501

        :return: The depreciation_calculation_method of this BookDepreciationSetting.  # noqa: E501
        :rtype: str
        """
        return self._depreciation_calculation_method

    @depreciation_calculation_method.setter
    def depreciation_calculation_method(self, depreciation_calculation_method):
        """Sets the depreciation_calculation_method of this BookDepreciationSetting.

        See Depreciation Calculation Methods  # noqa: E501

        :param depreciation_calculation_method: The depreciation_calculation_method of this BookDepreciationSetting.  # noqa: E501
        :type: str
        """
        allowed_values = ["Rate", "Life", "None", "None"]  # noqa: E501

        if depreciation_calculation_method:
            if depreciation_calculation_method not in allowed_values:
                raise ValueError(
                    "Invalid value for `depreciation_calculation_method` ({0}), must be one of {1}".format(  # noqa: E501
                        depreciation_calculation_method, allowed_values
                    )
                )

        self._depreciation_calculation_method = depreciation_calculation_method

    @property
    def depreciable_object_id(self):
        """Gets the depreciable_object_id of this BookDepreciationSetting.  # noqa: E501

        Unique Xero identifier for the depreciable object  # noqa: E501

        :return: The depreciable_object_id of this BookDepreciationSetting.  # noqa: E501
        :rtype: str
        """
        return self._depreciable_object_id

    @depreciable_object_id.setter
    def depreciable_object_id(self, depreciable_object_id):
        """Sets the depreciable_object_id of this BookDepreciationSetting.

        Unique Xero identifier for the depreciable object  # noqa: E501

        :param depreciable_object_id: The depreciable_object_id of this BookDepreciationSetting.  # noqa: E501
        :type: str
        """

        self._depreciable_object_id = depreciable_object_id

    @property
    def depreciable_object_type(self):
        """Gets the depreciable_object_type of this BookDepreciationSetting.  # noqa: E501

        The type of asset object  # noqa: E501

        :return: The depreciable_object_type of this BookDepreciationSetting.  # noqa: E501
        :rtype: str
        """
        return self._depreciable_object_type

    @depreciable_object_type.setter
    def depreciable_object_type(self, depreciable_object_type):
        """Sets the depreciable_object_type of this BookDepreciationSetting.

        The type of asset object  # noqa: E501

        :param depreciable_object_type: The depreciable_object_type of this BookDepreciationSetting.  # noqa: E501
        :type: str
        """

        self._depreciable_object_type = depreciable_object_type

    @property
    def book_effective_date_of_change_id(self):
        """Gets the book_effective_date_of_change_id of this BookDepreciationSetting.  # noqa: E501

        Unique Xero identifier for the effective date change  # noqa: E501

        :return: The book_effective_date_of_change_id of this BookDepreciationSetting.  # noqa: E501
        :rtype: str
        """
        return self._book_effective_date_of_change_id

    @book_effective_date_of_change_id.setter
    def book_effective_date_of_change_id(self, book_effective_date_of_change_id):
        """Sets the book_effective_date_of_change_id of this BookDepreciationSetting.

        Unique Xero identifier for the effective date change  # noqa: E501

        :param book_effective_date_of_change_id: The book_effective_date_of_change_id of this BookDepreciationSetting.  # noqa: E501
        :type: str
        """

        self._book_effective_date_of_change_id = book_effective_date_of_change_id



# coding: utf-8

"""
    Xero Payroll NZ

    This is the Xero Payroll API for orgs in the NZ region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class InvalidField(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"name": "str", "reason": "str"}

    attribute_map = {"name": "name", "reason": "reason"}

    def __init__(self, name=None, reason=None):  # noqa: E501
        """InvalidField - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._reason = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if reason is not None:
            self.reason = reason

    @property
    def name(self):
        """Gets the name of this InvalidField.  # noqa: E501

        The name of the field that caused the error  # noqa: E501

        :return: The name of this InvalidField.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InvalidField.

        The name of the field that caused the error  # noqa: E501

        :param name: The name of this InvalidField.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def reason(self):
        """Gets the reason of this InvalidField.  # noqa: E501

        The reason the error occurred  # noqa: E501

        :return: The reason of this InvalidField.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this InvalidField.

        The reason the error occurred  # noqa: E501

        :param reason: The reason of this InvalidField.  # noqa: E501
        :type: str
        """

        self._reason = reason



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class PurchaseOrder(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "contact": "Contact",
        "line_items": "list[LineItem]",
        "date": "date[ms-format]",
        "delivery_date": "date[ms-format]",
        "line_amount_types": "LineAmountTypes",
        "purchase_order_number": "str",
        "reference": "str",
        "branding_theme_id": "str",
        "currency_code": "CurrencyCode",
        "status": "str",
        "sent_to_contact": "bool",
        "delivery_address": "str",
        "attention_to": "str",
        "telephone": "str",
        "delivery_instructions": "str",
        "expected_arrival_date": "date[ms-format]",
        "purchase_order_id": "str",
        "currency_rate": "float",
        "sub_total": "float",
        "total_tax": "float",
        "total": "float",
        "total_discount": "float",
        "has_attachments": "bool",
        "updated_date_utc": "datetime[ms-format]",
        "status_attribute_string": "str",
        "validation_errors": "list[ValidationError]",
        "warnings": "list[ValidationError]",
        "attachments": "list[Attachment]",
    }

    attribute_map = {
        "contact": "Contact",
        "line_items": "LineItems",
        "date": "Date",
        "delivery_date": "DeliveryDate",
        "line_amount_types": "LineAmountTypes",
        "purchase_order_number": "PurchaseOrderNumber",
        "reference": "Reference",
        "branding_theme_id": "BrandingThemeID",
        "currency_code": "CurrencyCode",
        "status": "Status",
        "sent_to_contact": "SentToContact",
        "delivery_address": "DeliveryAddress",
        "attention_to": "AttentionTo",
        "telephone": "Telephone",
        "delivery_instructions": "DeliveryInstructions",
        "expected_arrival_date": "ExpectedArrivalDate",
        "purchase_order_id": "PurchaseOrderID",
        "currency_rate": "CurrencyRate",
        "sub_total": "SubTotal",
        "total_tax": "TotalTax",
        "total": "Total",
        "total_discount": "TotalDiscount",
        "has_attachments": "HasAttachments",
        "updated_date_utc": "UpdatedDateUTC",
        "status_attribute_string": "StatusAttributeString",
        "validation_errors": "ValidationErrors",
        "warnings": "Warnings",
        "attachments": "Attachments",
    }

    def __init__(
        self,
        contact=None,
        line_items=None,
        date=None,
        delivery_date=None,
        line_amount_types=None,
        purchase_order_number=None,
        reference=None,
        branding_theme_id=None,
        currency_code=None,
        status=None,
        sent_to_contact=None,
        delivery_address=None,
        attention_to=None,
        telephone=None,
        delivery_instructions=None,
        expected_arrival_date=None,
        purchase_order_id=None,
        currency_rate=None,
        sub_total=None,
        total_tax=None,
        total=None,
        total_discount=None,
        has_attachments=False,
        updated_date_utc=None,
        status_attribute_string=None,
        validation_errors=None,
        warnings=None,
        attachments=None,
    ):  # noqa: E501
        """PurchaseOrder - a model defined in OpenAPI"""  # noqa: E501

        self._contact = None
        self._line_items = None
        self._date = None
        self._delivery_date = None
        self._line_amount_types = None
        self._purchase_order_number = None
        self._reference = None
        self._branding_theme_id = None
        self._currency_code = None
        self._status = None
        self._sent_to_contact = None
        self._delivery_address = None
        self._attention_to = None
        self._telephone = None
        self._delivery_instructions = None
        self._expected_arrival_date = None
        self._purchase_order_id = None
        self._currency_rate = None
        self._sub_total = None
        self._total_tax = None
        self._total = None
        self._total_discount = None
        self._has_attachments = None
        self._updated_date_utc = None
        self._status_attribute_string = None
        self._validation_errors = None
        self._warnings = None
        self._attachments = None
        self.discriminator = None

        if contact is not None:
            self.contact = contact
        if line_items is not None:
            self.line_items = line_items
        if date is not None:
            self.date = date
        if delivery_date is not None:
            self.delivery_date = delivery_date
        if line_amount_types is not None:
            self.line_amount_types = line_amount_types
        if purchase_order_number is not None:
            self.purchase_order_number = purchase_order_number
        if reference is not None:
            self.reference = reference
        if branding_theme_id is not None:
            self.branding_theme_id = branding_theme_id
        if currency_code is not None:
            self.currency_code = currency_code
        if status is not None:
            self.status = status
        if sent_to_contact is not None:
            self.sent_to_contact = sent_to_contact
        if delivery_address is not None:
            self.delivery_address = delivery_address
        if attention_to is not None:
            self.attention_to = attention_to
        if telephone is not None:
            self.telephone = telephone
        if delivery_instructions is not None:
            self.delivery_instructions = delivery_instructions
        if expected_arrival_date is not None:
            self.expected_arrival_date = expected_arrival_date
        if purchase_order_id is not None:
            self.purchase_order_id = purchase_order_id
        if currency_rate is not None:
            self.currency_rate = currency_rate
        if sub_total is not None:
            self.sub_total = sub_total
        if total_tax is not None:
            self.total_tax = total_tax
        if total is not None:
            self.total = total
        if total_discount is not None:
            self.total_discount = total_discount
        if has_attachments is not None:
            self.has_attachments = has_attachments
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if status_attribute_string is not None:
            self.status_attribute_string = status_attribute_string
        if validation_errors is not None:
            self.validation_errors = validation_errors
        if warnings is not None:
            self.warnings = warnings
        if attachments is not None:
            self.attachments = attachments

    @property
    def contact(self):
        """Gets the contact of this PurchaseOrder.  # noqa: E501


        :return: The contact of this PurchaseOrder.  # noqa: E501
        :rtype: Contact
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """Sets the contact of this PurchaseOrder.


        :param contact: The contact of this PurchaseOrder.  # noqa: E501
        :type: Contact
        """

        self._contact = contact

    @property
    def line_items(self):
        """Gets the line_items of this PurchaseOrder.  # noqa: E501

        See LineItems  # noqa: E501

        :return: The line_items of this PurchaseOrder.  # noqa: E501
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this PurchaseOrder.

        See LineItems  # noqa: E501

        :param line_items: The line_items of this PurchaseOrder.  # noqa: E501
        :type: list[LineItem]
        """

        self._line_items = line_items

    @property
    def date(self):
        """Gets the date of this PurchaseOrder.  # noqa: E501

        Date purchase order was issued – YYYY-MM-DD. If the Date element is not specified then it will default to the current date based on the timezone setting of the organisation  # noqa: E501

        :return: The date of this PurchaseOrder.  # noqa: E501
        :rtype: date
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this PurchaseOrder.

        Date purchase order was issued – YYYY-MM-DD. If the Date element is not specified then it will default to the current date based on the timezone setting of the organisation  # noqa: E501

        :param date: The date of this PurchaseOrder.  # noqa: E501
        :type: date
        """

        self._date = date

    @property
    def delivery_date(self):
        """Gets the delivery_date of this PurchaseOrder.  # noqa: E501

        Date the goods are to be delivered – YYYY-MM-DD  # noqa: E501

        :return: The delivery_date of this PurchaseOrder.  # noqa: E501
        :rtype: date
        """
        return self._delivery_date

    @delivery_date.setter
    def delivery_date(self, delivery_date):
        """Sets the delivery_date of this PurchaseOrder.

        Date the goods are to be delivered – YYYY-MM-DD  # noqa: E501

        :param delivery_date: The delivery_date of this PurchaseOrder.  # noqa: E501
        :type: date
        """

        self._delivery_date = delivery_date

    @property
    def line_amount_types(self):
        """Gets the line_amount_types of this PurchaseOrder.  # noqa: E501


        :return: The line_amount_types of this PurchaseOrder.  # noqa: E501
        :rtype: LineAmountTypes
        """
        return self._line_amount_types

    @line_amount_types.setter
    def line_amount_types(self, line_amount_types):
        """Sets the line_amount_types of this PurchaseOrder.


        :param line_amount_types: The line_amount_types of this PurchaseOrder.  # noqa: E501
        :type: LineAmountTypes
        """

        self._line_amount_types = line_amount_types

    @property
    def purchase_order_number(self):
        """Gets the purchase_order_number of this PurchaseOrder.  # noqa: E501

        Unique alpha numeric code identifying purchase order (when missing will auto-generate from your Organisation Invoice Settings)  # noqa: E501

        :return: The purchase_order_number of this PurchaseOrder.  # noqa: E501
        :rtype: str
        """
        return self._purchase_order_number

    @purchase_order_number.setter
    def purchase_order_number(self, purchase_order_number):
        """Sets the purchase_order_number of this PurchaseOrder.

        Unique alpha numeric code identifying purchase order (when missing will auto-generate from your Organisation Invoice Settings)  # noqa: E501

        :param purchase_order_number: The purchase_order_number of this PurchaseOrder.  # noqa: E501
        :type: str
        """

        self._purchase_order_number = purchase_order_number

    @property
    def reference(self):
        """Gets the reference of this PurchaseOrder.  # noqa: E501

        Additional reference number  # noqa: E501

        :return: The reference of this PurchaseOrder.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this PurchaseOrder.

        Additional reference number  # noqa: E501

        :param reference: The reference of this PurchaseOrder.  # noqa: E501
        :type: str
        """

        self._reference = reference

    @property
    def branding_theme_id(self):
        """Gets the branding_theme_id of this PurchaseOrder.  # noqa: E501

        See BrandingThemes  # noqa: E501

        :return: The branding_theme_id of this PurchaseOrder.  # noqa: E501
        :rtype: str
        """
        return self._branding_theme_id

    @branding_theme_id.setter
    def branding_theme_id(self, branding_theme_id):
        """Sets the branding_theme_id of this PurchaseOrder.

        See BrandingThemes  # noqa: E501

        :param branding_theme_id: The branding_theme_id of this PurchaseOrder.  # noqa: E501
        :type: str
        """

        self._branding_theme_id = branding_theme_id

    @property
    def currency_code(self):
        """Gets the currency_code of this PurchaseOrder.  # noqa: E501


        :return: The currency_code of this PurchaseOrder.  # noqa: E501
        :rtype: CurrencyCode
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this PurchaseOrder.


        :param currency_code: The currency_code of this PurchaseOrder.  # noqa: E501
        :type: CurrencyCode
        """

        self._currency_code = currency_code

    @property
    def status(self):
        """Gets the status of this PurchaseOrder.  # noqa: E501

        See Purchase Order Status Codes  # noqa: E501

        :return: The status of this PurchaseOrder.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PurchaseOrder.

        See Purchase Order Status Codes  # noqa: E501

        :param status: The status of this PurchaseOrder.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "DRAFT",
            "SUBMITTED",
            "AUTHORISED",
            "BILLED",
            "DELETED",
            "None",
        ]  # noqa: E501

        if status:
            if status not in allowed_values:
                raise ValueError(
                    "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                        status, allowed_values
                    )
                )

        self._status = status

    @property
    def sent_to_contact(self):
        """Gets the sent_to_contact of this PurchaseOrder.  # noqa: E501

        Boolean to set whether the purchase order should be marked as “sent”. This can be set only on purchase orders that have been approved or billed  # noqa: E501

        :return: The sent_to_contact of this PurchaseOrder.  # noqa: E501
        :rtype: bool
        """
        return self._sent_to_contact

    @sent_to_contact.setter
    def sent_to_contact(self, sent_to_contact):
        """Sets the sent_to_contact of this PurchaseOrder.

        Boolean to set whether the purchase order should be marked as “sent”. This can be set only on purchase orders that have been approved or billed  # noqa: E501

        :param sent_to_contact: The sent_to_contact of this PurchaseOrder.  # noqa: E501
        :type: bool
        """

        self._sent_to_contact = sent_to_contact

    @property
    def delivery_address(self):
        """Gets the delivery_address of this PurchaseOrder.  # noqa: E501

        The address the goods are to be delivered to  # noqa: E501

        :return: The delivery_address of this PurchaseOrder.  # noqa: E501
        :rtype: str
        """
        return self._delivery_address

    @delivery_address.setter
    def delivery_address(self, delivery_address):
        """Sets the delivery_address of this PurchaseOrder.

        The address the goods are to be delivered to  # noqa: E501

        :param delivery_address: The delivery_address of this PurchaseOrder.  # noqa: E501
        :type: str
        """

        self._delivery_address = delivery_address

    @property
    def attention_to(self):
        """Gets the attention_to of this PurchaseOrder.  # noqa: E501

        The person that the delivery is going to  # noqa: E501

        :return: The attention_to of this PurchaseOrder.  # noqa: E501
        :rtype: str
        """
        return self._attention_to

    @attention_to.setter
    def attention_to(self, attention_to):
        """Sets the attention_to of this PurchaseOrder.

        The person that the delivery is going to  # noqa: E501

        :param attention_to: The attention_to of this PurchaseOrder.  # noqa: E501
        :type: str
        """

        self._attention_to = attention_to

    @property
    def telephone(self):
        """Gets the telephone of this PurchaseOrder.  # noqa: E501

        The phone number for the person accepting the delivery  # noqa: E501

        :return: The telephone of this PurchaseOrder.  # noqa: E501
        :rtype: str
        """
        return self._telephone

    @telephone.setter
    def telephone(self, telephone):
        """Sets the telephone of this PurchaseOrder.

        The phone number for the person accepting the delivery  # noqa: E501

        :param telephone: The telephone of this PurchaseOrder.  # noqa: E501
        :type: str
        """

        self._telephone = telephone

    @property
    def delivery_instructions(self):
        """Gets the delivery_instructions of this PurchaseOrder.  # noqa: E501

        A free text feild for instructions (500 characters max)  # noqa: E501

        :return: The delivery_instructions of this PurchaseOrder.  # noqa: E501
        :rtype: str
        """
        return self._delivery_instructions

    @delivery_instructions.setter
    def delivery_instructions(self, delivery_instructions):
        """Sets the delivery_instructions of this PurchaseOrder.

        A free text feild for instructions (500 characters max)  # noqa: E501

        :param delivery_instructions: The delivery_instructions of this PurchaseOrder.  # noqa: E501
        :type: str
        """

        self._delivery_instructions = delivery_instructions

    @property
    def expected_arrival_date(self):
        """Gets the expected_arrival_date of this PurchaseOrder.  # noqa: E501

        The date the goods are expected to arrive.  # noqa: E501

        :return: The expected_arrival_date of this PurchaseOrder.  # noqa: E501
        :rtype: date
        """
        return self._expected_arrival_date

    @expected_arrival_date.setter
    def expected_arrival_date(self, expected_arrival_date):
        """Sets the expected_arrival_date of this PurchaseOrder.

        The date the goods are expected to arrive.  # noqa: E501

        :param expected_arrival_date: The expected_arrival_date of this PurchaseOrder.  # noqa: E501
        :type: date
        """

        self._expected_arrival_date = expected_arrival_date

    @property
    def purchase_order_id(self):
        """Gets the purchase_order_id of this PurchaseOrder.  # noqa: E501

        Xero generated unique identifier for purchase order  # noqa: E501

        :return: The purchase_order_id of this PurchaseOrder.  # noqa: E501
        :rtype: str
        """
        return self._purchase_order_id

    @purchase_order_id.setter
    def purchase_order_id(self, purchase_order_id):
        """Sets the purchase_order_id of this PurchaseOrder.

        Xero generated unique identifier for purchase order  # noqa: E501

        :param purchase_order_id: The purchase_order_id of this PurchaseOrder.  # noqa: E501
        :type: str
        """

        self._purchase_order_id = purchase_order_id

    @property
    def currency_rate(self):
        """Gets the currency_rate of this PurchaseOrder.  # noqa: E501

        The currency rate for a multicurrency purchase order. If no rate is specified, the XE.com day rate is used.  # noqa: E501

        :return: The currency_rate of this PurchaseOrder.  # noqa: E501
        :rtype: float
        """
        return self._currency_rate

    @currency_rate.setter
    def currency_rate(self, currency_rate):
        """Sets the currency_rate of this PurchaseOrder.

        The currency rate for a multicurrency purchase order. If no rate is specified, the XE.com day rate is used.  # noqa: E501

        :param currency_rate: The currency_rate of this PurchaseOrder.  # noqa: E501
        :type: float
        """

        self._currency_rate = currency_rate

    @property
    def sub_total(self):
        """Gets the sub_total of this PurchaseOrder.  # noqa: E501

        Total of purchase order excluding taxes  # noqa: E501

        :return: The sub_total of this PurchaseOrder.  # noqa: E501
        :rtype: float
        """
        return self._sub_total

    @sub_total.setter
    def sub_total(self, sub_total):
        """Sets the sub_total of this PurchaseOrder.

        Total of purchase order excluding taxes  # noqa: E501

        :param sub_total: The sub_total of this PurchaseOrder.  # noqa: E501
        :type: float
        """

        self._sub_total = sub_total

    @property
    def total_tax(self):
        """Gets the total_tax of this PurchaseOrder.  # noqa: E501

        Total tax on purchase order  # noqa: E501

        :return: The total_tax of this PurchaseOrder.  # noqa: E501
        :rtype: float
        """
        return self._total_tax

    @total_tax.setter
    def total_tax(self, total_tax):
        """Sets the total_tax of this PurchaseOrder.

        Total tax on purchase order  # noqa: E501

        :param total_tax: The total_tax of this PurchaseOrder.  # noqa: E501
        :type: float
        """

        self._total_tax = total_tax

    @property
    def total(self):
        """Gets the total of this PurchaseOrder.  # noqa: E501

        Total of Purchase Order tax inclusive (i.e. SubTotal + TotalTax)  # noqa: E501

        :return: The total of this PurchaseOrder.  # noqa: E501
        :rtype: float
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this PurchaseOrder.

        Total of Purchase Order tax inclusive (i.e. SubTotal + TotalTax)  # noqa: E501

        :param total: The total of this PurchaseOrder.  # noqa: E501
        :type: float
        """

        self._total = total

    @property
    def total_discount(self):
        """Gets the total_discount of this PurchaseOrder.  # noqa: E501

        Total of discounts applied on the purchase order line items  # noqa: E501

        :return: The total_discount of this PurchaseOrder.  # noqa: E501
        :rtype: float
        """
        return self._total_discount

    @total_discount.setter
    def total_discount(self, total_discount):
        """Sets the total_discount of this PurchaseOrder.

        Total of discounts applied on the purchase order line items  # noqa: E501

        :param total_discount: The total_discount of this PurchaseOrder.  # noqa: E501
        :type: float
        """

        self._total_discount = total_discount

    @property
    def has_attachments(self):
        """Gets the has_attachments of this PurchaseOrder.  # noqa: E501

        boolean to indicate if a purchase order has an attachment  # noqa: E501

        :return: The has_attachments of this PurchaseOrder.  # noqa: E501
        :rtype: bool
        """
        return self._has_attachments

    @has_attachments.setter
    def has_attachments(self, has_attachments):
        """Sets the has_attachments of this PurchaseOrder.

        boolean to indicate if a purchase order has an attachment  # noqa: E501

        :param has_attachments: The has_attachments of this PurchaseOrder.  # noqa: E501
        :type: bool
        """

        self._has_attachments = has_attachments

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this PurchaseOrder.  # noqa: E501

        Last modified date UTC format  # noqa: E501

        :return: The updated_date_utc of this PurchaseOrder.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this PurchaseOrder.

        Last modified date UTC format  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this PurchaseOrder.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def status_attribute_string(self):
        """Gets the status_attribute_string of this PurchaseOrder.  # noqa: E501

        A string to indicate if a invoice status  # noqa: E501

        :return: The status_attribute_string of this PurchaseOrder.  # noqa: E501
        :rtype: str
        """
        return self._status_attribute_string

    @status_attribute_string.setter
    def status_attribute_string(self, status_attribute_string):
        """Sets the status_attribute_string of this PurchaseOrder.

        A string to indicate if a invoice status  # noqa: E501

        :param status_attribute_string: The status_attribute_string of this PurchaseOrder.  # noqa: E501
        :type: str
        """

        self._status_attribute_string = status_attribute_string

    @property
    def validation_errors(self):
        """Gets the validation_errors of this PurchaseOrder.  # noqa: E501

        Displays array of validation error messages from the API  # noqa: E501

        :return: The validation_errors of this PurchaseOrder.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this PurchaseOrder.

        Displays array of validation error messages from the API  # noqa: E501

        :param validation_errors: The validation_errors of this PurchaseOrder.  # noqa: E501
        :type: list[ValidationError]
        """

        self._validation_errors = validation_errors

    @property
    def warnings(self):
        """Gets the warnings of this PurchaseOrder.  # noqa: E501

        Displays array of warning messages from the API  # noqa: E501

        :return: The warnings of this PurchaseOrder.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this PurchaseOrder.

        Displays array of warning messages from the API  # noqa: E501

        :param warnings: The warnings of this PurchaseOrder.  # noqa: E501
        :type: list[ValidationError]
        """

        self._warnings = warnings

    @property
    def attachments(self):
        """Gets the attachments of this PurchaseOrder.  # noqa: E501

        Displays array of attachments from the API  # noqa: E501

        :return: The attachments of this PurchaseOrder.  # noqa: E501
        :rtype: list[Attachment]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """Sets the attachments of this PurchaseOrder.

        Displays array of attachments from the API  # noqa: E501

        :param attachments: The attachments of this PurchaseOrder.  # noqa: E501
        :type: list[Attachment]
        """

        self._attachments = attachments



# coding: utf-8

# flake8: noqa
"""
    Xero OAuth 2 Identity Service API

    These endpoints are related to managing authentication tokens and identity for Xero API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


# import models into model package
from xero_python.identity.models.access_token import AccessToken
from xero_python.identity.models.connection import Connection
from xero_python.identity.models.refresh_token import RefreshToken



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class ImportSummaryAccounts(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "total": "int",
        "new": "int",
        "updated": "int",
        "deleted": "int",
        "locked": "int",
        "system": "int",
        "errored": "int",
        "present": "bool",
        "new_or_updated": "int",
    }

    attribute_map = {
        "total": "Total",
        "new": "New",
        "updated": "Updated",
        "deleted": "Deleted",
        "locked": "Locked",
        "system": "System",
        "errored": "Errored",
        "present": "Present",
        "new_or_updated": "NewOrUpdated",
    }

    def __init__(
        self,
        total=None,
        new=None,
        updated=None,
        deleted=None,
        locked=None,
        system=None,
        errored=None,
        present=None,
        new_or_updated=None,
    ):  # noqa: E501
        """ImportSummaryAccounts - a model defined in OpenAPI"""  # noqa: E501

        self._total = None
        self._new = None
        self._updated = None
        self._deleted = None
        self._locked = None
        self._system = None
        self._errored = None
        self._present = None
        self._new_or_updated = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if new is not None:
            self.new = new
        if updated is not None:
            self.updated = updated
        if deleted is not None:
            self.deleted = deleted
        if locked is not None:
            self.locked = locked
        if system is not None:
            self.system = system
        if errored is not None:
            self.errored = errored
        if present is not None:
            self.present = present
        if new_or_updated is not None:
            self.new_or_updated = new_or_updated

    @property
    def total(self):
        """Gets the total of this ImportSummaryAccounts.  # noqa: E501

        The total number of accounts in the org  # noqa: E501

        :return: The total of this ImportSummaryAccounts.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ImportSummaryAccounts.

        The total number of accounts in the org  # noqa: E501

        :param total: The total of this ImportSummaryAccounts.  # noqa: E501
        :type: int
        """

        self._total = total

    @property
    def new(self):
        """Gets the new of this ImportSummaryAccounts.  # noqa: E501

        The number of new accounts created  # noqa: E501

        :return: The new of this ImportSummaryAccounts.  # noqa: E501
        :rtype: int
        """
        return self._new

    @new.setter
    def new(self, new):
        """Sets the new of this ImportSummaryAccounts.

        The number of new accounts created  # noqa: E501

        :param new: The new of this ImportSummaryAccounts.  # noqa: E501
        :type: int
        """

        self._new = new

    @property
    def updated(self):
        """Gets the updated of this ImportSummaryAccounts.  # noqa: E501

        The number of accounts updated  # noqa: E501

        :return: The updated of this ImportSummaryAccounts.  # noqa: E501
        :rtype: int
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this ImportSummaryAccounts.

        The number of accounts updated  # noqa: E501

        :param updated: The updated of this ImportSummaryAccounts.  # noqa: E501
        :type: int
        """

        self._updated = updated

    @property
    def deleted(self):
        """Gets the deleted of this ImportSummaryAccounts.  # noqa: E501

        The number of accounts deleted  # noqa: E501

        :return: The deleted of this ImportSummaryAccounts.  # noqa: E501
        :rtype: int
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this ImportSummaryAccounts.

        The number of accounts deleted  # noqa: E501

        :param deleted: The deleted of this ImportSummaryAccounts.  # noqa: E501
        :type: int
        """

        self._deleted = deleted

    @property
    def locked(self):
        """Gets the locked of this ImportSummaryAccounts.  # noqa: E501

        The number of locked accounts  # noqa: E501

        :return: The locked of this ImportSummaryAccounts.  # noqa: E501
        :rtype: int
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this ImportSummaryAccounts.

        The number of locked accounts  # noqa: E501

        :param locked: The locked of this ImportSummaryAccounts.  # noqa: E501
        :type: int
        """

        self._locked = locked

    @property
    def system(self):
        """Gets the system of this ImportSummaryAccounts.  # noqa: E501

        The number of system accounts  # noqa: E501

        :return: The system of this ImportSummaryAccounts.  # noqa: E501
        :rtype: int
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this ImportSummaryAccounts.

        The number of system accounts  # noqa: E501

        :param system: The system of this ImportSummaryAccounts.  # noqa: E501
        :type: int
        """

        self._system = system

    @property
    def errored(self):
        """Gets the errored of this ImportSummaryAccounts.  # noqa: E501

        The number of accounts that had an error  # noqa: E501

        :return: The errored of this ImportSummaryAccounts.  # noqa: E501
        :rtype: int
        """
        return self._errored

    @errored.setter
    def errored(self, errored):
        """Sets the errored of this ImportSummaryAccounts.

        The number of accounts that had an error  # noqa: E501

        :param errored: The errored of this ImportSummaryAccounts.  # noqa: E501
        :type: int
        """

        self._errored = errored

    @property
    def present(self):
        """Gets the present of this ImportSummaryAccounts.  # noqa: E501


        :return: The present of this ImportSummaryAccounts.  # noqa: E501
        :rtype: bool
        """
        return self._present

    @present.setter
    def present(self, present):
        """Sets the present of this ImportSummaryAccounts.


        :param present: The present of this ImportSummaryAccounts.  # noqa: E501
        :type: bool
        """

        self._present = present

    @property
    def new_or_updated(self):
        """Gets the new_or_updated of this ImportSummaryAccounts.  # noqa: E501

        The number of new or updated accounts  # noqa: E501

        :return: The new_or_updated of this ImportSummaryAccounts.  # noqa: E501
        :rtype: int
        """
        return self._new_or_updated

    @new_or_updated.setter
    def new_or_updated(self, new_or_updated):
        """Sets the new_or_updated of this ImportSummaryAccounts.

        The number of new or updated accounts  # noqa: E501

        :param new_or_updated: The new_or_updated of this ImportSummaryAccounts.  # noqa: E501
        :type: int
        """

        self._new_or_updated = new_or_updated



# coding: utf-8

"""
    Xero Files API

    These endpoints are specific to Xero Files API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Folders(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"folders": "list[Folder]"}

    attribute_map = {"folders": "Folders"}

    def __init__(self, folders=None):  # noqa: E501
        """Folders - a model defined in OpenAPI"""  # noqa: E501

        self._folders = None
        self.discriminator = None

        if folders is not None:
            self.folders = folders

    @property
    def folders(self):
        """Gets the folders of this Folders.  # noqa: E501


        :return: The folders of this Folders.  # noqa: E501
        :rtype: list[Folder]
        """
        return self._folders

    @folders.setter
    def folders(self, folders):
        """Sets the folders of this Folders.


        :param folders: The folders of this Folders.  # noqa: E501
        :type: list[Folder]
        """

        self._folders = folders



#!/usr/bin/env python

"""The setup script."""
import re

from setuptools import setup, find_packages

COMMENT_RE = re.compile(r"(^|\s+)#.*$")


def load_requirements(file_name):
    requirements = []
    with open(file_name, "r") as req_file:
        for line in req_file:
            line = COMMENT_RE.sub("", line)
            line = line.strip()
            if line:
                requirements.append(line)
    return requirements


def read_file(filename):
    with open(filename) as fp:
        return fp.read()


setup(
    author="Xero Developer API",
    author_email="api@xero.com",
    python_requires=">=3.5",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    description="Official Python sdk for Xero API generated by OpenAPI spec for oAuth2",
    install_requires=load_requirements("requirements.txt"),
    license="MIT license",
    long_description="\n\n".join((read_file("README.md"), read_file("HISTORY.md"))),
    long_description_content_type="text/markdown",
    include_package_data=True,
    keywords="xero python sdk API oAuth",
    name="xero_python",
    packages=find_packages(include=["xero_python", "xero_python.*"]),
    version="1.5.2",
)



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Quote(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "quote_id": "str",
        "quote_number": "str",
        "reference": "str",
        "terms": "str",
        "contact": "Contact",
        "line_items": "list[LineItem]",
        "date": "date[ms-format]",
        "date_string": "str",
        "expiry_date": "date[ms-format]",
        "expiry_date_string": "str",
        "status": "QuoteStatusCodes",
        "currency_code": "CurrencyCode",
        "currency_rate": "float",
        "sub_total": "float",
        "total_tax": "float",
        "total": "float",
        "total_discount": "float",
        "title": "str",
        "summary": "str",
        "branding_theme_id": "str",
        "updated_date_utc": "datetime[ms-format]",
        "line_amount_types": "QuoteLineAmountTypes",
        "status_attribute_string": "str",
        "validation_errors": "list[ValidationError]",
    }

    attribute_map = {
        "quote_id": "QuoteID",
        "quote_number": "QuoteNumber",
        "reference": "Reference",
        "terms": "Terms",
        "contact": "Contact",
        "line_items": "LineItems",
        "date": "Date",
        "date_string": "DateString",
        "expiry_date": "ExpiryDate",
        "expiry_date_string": "ExpiryDateString",
        "status": "Status",
        "currency_code": "CurrencyCode",
        "currency_rate": "CurrencyRate",
        "sub_total": "SubTotal",
        "total_tax": "TotalTax",
        "total": "Total",
        "total_discount": "TotalDiscount",
        "title": "Title",
        "summary": "Summary",
        "branding_theme_id": "BrandingThemeID",
        "updated_date_utc": "UpdatedDateUTC",
        "line_amount_types": "LineAmountTypes",
        "status_attribute_string": "StatusAttributeString",
        "validation_errors": "ValidationErrors",
    }

    def __init__(
        self,
        quote_id=None,
        quote_number=None,
        reference=None,
        terms=None,
        contact=None,
        line_items=None,
        date=None,
        date_string=None,
        expiry_date=None,
        expiry_date_string=None,
        status=None,
        currency_code=None,
        currency_rate=None,
        sub_total=None,
        total_tax=None,
        total=None,
        total_discount=None,
        title=None,
        summary=None,
        branding_theme_id=None,
        updated_date_utc=None,
        line_amount_types=None,
        status_attribute_string=None,
        validation_errors=None,
    ):  # noqa: E501
        """Quote - a model defined in OpenAPI"""  # noqa: E501

        self._quote_id = None
        self._quote_number = None
        self._reference = None
        self._terms = None
        self._contact = None
        self._line_items = None
        self._date = None
        self._date_string = None
        self._expiry_date = None
        self._expiry_date_string = None
        self._status = None
        self._currency_code = None
        self._currency_rate = None
        self._sub_total = None
        self._total_tax = None
        self._total = None
        self._total_discount = None
        self._title = None
        self._summary = None
        self._branding_theme_id = None
        self._updated_date_utc = None
        self._line_amount_types = None
        self._status_attribute_string = None
        self._validation_errors = None
        self.discriminator = None

        if quote_id is not None:
            self.quote_id = quote_id
        if quote_number is not None:
            self.quote_number = quote_number
        if reference is not None:
            self.reference = reference
        if terms is not None:
            self.terms = terms
        if contact is not None:
            self.contact = contact
        if line_items is not None:
            self.line_items = line_items
        if date is not None:
            self.date = date
        if date_string is not None:
            self.date_string = date_string
        if expiry_date is not None:
            self.expiry_date = expiry_date
        if expiry_date_string is not None:
            self.expiry_date_string = expiry_date_string
        if status is not None:
            self.status = status
        if currency_code is not None:
            self.currency_code = currency_code
        if currency_rate is not None:
            self.currency_rate = currency_rate
        if sub_total is not None:
            self.sub_total = sub_total
        if total_tax is not None:
            self.total_tax = total_tax
        if total is not None:
            self.total = total
        if total_discount is not None:
            self.total_discount = total_discount
        if title is not None:
            self.title = title
        if summary is not None:
            self.summary = summary
        if branding_theme_id is not None:
            self.branding_theme_id = branding_theme_id
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if line_amount_types is not None:
            self.line_amount_types = line_amount_types
        if status_attribute_string is not None:
            self.status_attribute_string = status_attribute_string
        if validation_errors is not None:
            self.validation_errors = validation_errors

    @property
    def quote_id(self):
        """Gets the quote_id of this Quote.  # noqa: E501

        QuoteID GUID is automatically generated and is returned after create or GET.  # noqa: E501

        :return: The quote_id of this Quote.  # noqa: E501
        :rtype: str
        """
        return self._quote_id

    @quote_id.setter
    def quote_id(self, quote_id):
        """Sets the quote_id of this Quote.

        QuoteID GUID is automatically generated and is returned after create or GET.  # noqa: E501

        :param quote_id: The quote_id of this Quote.  # noqa: E501
        :type: str
        """

        self._quote_id = quote_id

    @property
    def quote_number(self):
        """Gets the quote_number of this Quote.  # noqa: E501

        Unique alpha numeric code identifying a quote (Max Length = 255)  # noqa: E501

        :return: The quote_number of this Quote.  # noqa: E501
        :rtype: str
        """
        return self._quote_number

    @quote_number.setter
    def quote_number(self, quote_number):
        """Sets the quote_number of this Quote.

        Unique alpha numeric code identifying a quote (Max Length = 255)  # noqa: E501

        :param quote_number: The quote_number of this Quote.  # noqa: E501
        :type: str
        """
        if quote_number is not None and len(quote_number) > 255:
            raise ValueError(
                "Invalid value for `quote_number`, "
                "length must be less than or equal to `255`"
            )  # noqa: E501

        self._quote_number = quote_number

    @property
    def reference(self):
        """Gets the reference of this Quote.  # noqa: E501

        Additional reference number  # noqa: E501

        :return: The reference of this Quote.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this Quote.

        Additional reference number  # noqa: E501

        :param reference: The reference of this Quote.  # noqa: E501
        :type: str
        """
        if reference is not None and len(reference) > 4000:
            raise ValueError(
                "Invalid value for `reference`, "
                "length must be less than or equal to `4000`"
            )  # noqa: E501

        self._reference = reference

    @property
    def terms(self):
        """Gets the terms of this Quote.  # noqa: E501

        Terms of the quote  # noqa: E501

        :return: The terms of this Quote.  # noqa: E501
        :rtype: str
        """
        return self._terms

    @terms.setter
    def terms(self, terms):
        """Sets the terms of this Quote.

        Terms of the quote  # noqa: E501

        :param terms: The terms of this Quote.  # noqa: E501
        :type: str
        """
        if terms is not None and len(terms) > 4000:
            raise ValueError(
                "Invalid value for `terms`, "
                "length must be less than or equal to `4000`"
            )  # noqa: E501

        self._terms = terms

    @property
    def contact(self):
        """Gets the contact of this Quote.  # noqa: E501


        :return: The contact of this Quote.  # noqa: E501
        :rtype: Contact
        """
        return self._contact

    @contact.setter
    def contact(self, contact):
        """Sets the contact of this Quote.


        :param contact: The contact of this Quote.  # noqa: E501
        :type: Contact
        """

        self._contact = contact

    @property
    def line_items(self):
        """Gets the line_items of this Quote.  # noqa: E501

        See LineItems  # noqa: E501

        :return: The line_items of this Quote.  # noqa: E501
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this Quote.

        See LineItems  # noqa: E501

        :param line_items: The line_items of this Quote.  # noqa: E501
        :type: list[LineItem]
        """

        self._line_items = line_items

    @property
    def date(self):
        """Gets the date of this Quote.  # noqa: E501

        Date quote was issued – YYYY-MM-DD. If the Date element is not specified it will default to the current date based on the timezone setting of the organisation  # noqa: E501

        :return: The date of this Quote.  # noqa: E501
        :rtype: date
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this Quote.

        Date quote was issued – YYYY-MM-DD. If the Date element is not specified it will default to the current date based on the timezone setting of the organisation  # noqa: E501

        :param date: The date of this Quote.  # noqa: E501
        :type: date
        """

        self._date = date

    @property
    def date_string(self):
        """Gets the date_string of this Quote.  # noqa: E501

        Date the quote was issued (YYYY-MM-DD)  # noqa: E501

        :return: The date_string of this Quote.  # noqa: E501
        :rtype: str
        """
        return self._date_string

    @date_string.setter
    def date_string(self, date_string):
        """Sets the date_string of this Quote.

        Date the quote was issued (YYYY-MM-DD)  # noqa: E501

        :param date_string: The date_string of this Quote.  # noqa: E501
        :type: str
        """

        self._date_string = date_string

    @property
    def expiry_date(self):
        """Gets the expiry_date of this Quote.  # noqa: E501

        Date the quote expires – YYYY-MM-DD.  # noqa: E501

        :return: The expiry_date of this Quote.  # noqa: E501
        :rtype: date
        """
        return self._expiry_date

    @expiry_date.setter
    def expiry_date(self, expiry_date):
        """Sets the expiry_date of this Quote.

        Date the quote expires – YYYY-MM-DD.  # noqa: E501

        :param expiry_date: The expiry_date of this Quote.  # noqa: E501
        :type: date
        """

        self._expiry_date = expiry_date

    @property
    def expiry_date_string(self):
        """Gets the expiry_date_string of this Quote.  # noqa: E501

        Date the quote expires – YYYY-MM-DD.  # noqa: E501

        :return: The expiry_date_string of this Quote.  # noqa: E501
        :rtype: str
        """
        return self._expiry_date_string

    @expiry_date_string.setter
    def expiry_date_string(self, expiry_date_string):
        """Sets the expiry_date_string of this Quote.

        Date the quote expires – YYYY-MM-DD.  # noqa: E501

        :param expiry_date_string: The expiry_date_string of this Quote.  # noqa: E501
        :type: str
        """

        self._expiry_date_string = expiry_date_string

    @property
    def status(self):
        """Gets the status of this Quote.  # noqa: E501


        :return: The status of this Quote.  # noqa: E501
        :rtype: QuoteStatusCodes
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Quote.


        :param status: The status of this Quote.  # noqa: E501
        :type: QuoteStatusCodes
        """

        self._status = status

    @property
    def currency_code(self):
        """Gets the currency_code of this Quote.  # noqa: E501


        :return: The currency_code of this Quote.  # noqa: E501
        :rtype: CurrencyCode
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this Quote.


        :param currency_code: The currency_code of this Quote.  # noqa: E501
        :type: CurrencyCode
        """

        self._currency_code = currency_code

    @property
    def currency_rate(self):
        """Gets the currency_rate of this Quote.  # noqa: E501

        The currency rate for a multicurrency quote  # noqa: E501

        :return: The currency_rate of this Quote.  # noqa: E501
        :rtype: float
        """
        return self._currency_rate

    @currency_rate.setter
    def currency_rate(self, currency_rate):
        """Sets the currency_rate of this Quote.

        The currency rate for a multicurrency quote  # noqa: E501

        :param currency_rate: The currency_rate of this Quote.  # noqa: E501
        :type: float
        """

        self._currency_rate = currency_rate

    @property
    def sub_total(self):
        """Gets the sub_total of this Quote.  # noqa: E501

        Total of quote excluding taxes.  # noqa: E501

        :return: The sub_total of this Quote.  # noqa: E501
        :rtype: float
        """
        return self._sub_total

    @sub_total.setter
    def sub_total(self, sub_total):
        """Sets the sub_total of this Quote.

        Total of quote excluding taxes.  # noqa: E501

        :param sub_total: The sub_total of this Quote.  # noqa: E501
        :type: float
        """

        self._sub_total = sub_total

    @property
    def total_tax(self):
        """Gets the total_tax of this Quote.  # noqa: E501

        Total tax on quote  # noqa: E501

        :return: The total_tax of this Quote.  # noqa: E501
        :rtype: float
        """
        return self._total_tax

    @total_tax.setter
    def total_tax(self, total_tax):
        """Sets the total_tax of this Quote.

        Total tax on quote  # noqa: E501

        :param total_tax: The total_tax of this Quote.  # noqa: E501
        :type: float
        """

        self._total_tax = total_tax

    @property
    def total(self):
        """Gets the total of this Quote.  # noqa: E501

        Total of Quote tax inclusive (i.e. SubTotal + TotalTax). This will be ignored if it doesn’t equal the sum of the LineAmounts  # noqa: E501

        :return: The total of this Quote.  # noqa: E501
        :rtype: float
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this Quote.

        Total of Quote tax inclusive (i.e. SubTotal + TotalTax). This will be ignored if it doesn’t equal the sum of the LineAmounts  # noqa: E501

        :param total: The total of this Quote.  # noqa: E501
        :type: float
        """

        self._total = total

    @property
    def total_discount(self):
        """Gets the total_discount of this Quote.  # noqa: E501

        Total of discounts applied on the quote line items  # noqa: E501

        :return: The total_discount of this Quote.  # noqa: E501
        :rtype: float
        """
        return self._total_discount

    @total_discount.setter
    def total_discount(self, total_discount):
        """Sets the total_discount of this Quote.

        Total of discounts applied on the quote line items  # noqa: E501

        :param total_discount: The total_discount of this Quote.  # noqa: E501
        :type: float
        """

        self._total_discount = total_discount

    @property
    def title(self):
        """Gets the title of this Quote.  # noqa: E501

        Title text for the quote  # noqa: E501

        :return: The title of this Quote.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Quote.

        Title text for the quote  # noqa: E501

        :param title: The title of this Quote.  # noqa: E501
        :type: str
        """
        if title is not None and len(title) > 100:
            raise ValueError(
                "Invalid value for `title`, "
                "length must be less than or equal to `100`"
            )  # noqa: E501

        self._title = title

    @property
    def summary(self):
        """Gets the summary of this Quote.  # noqa: E501

        Summary text for the quote  # noqa: E501

        :return: The summary of this Quote.  # noqa: E501
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this Quote.

        Summary text for the quote  # noqa: E501

        :param summary: The summary of this Quote.  # noqa: E501
        :type: str
        """
        if summary is not None and len(summary) > 3000:
            raise ValueError(
                "Invalid value for `summary`, "
                "length must be less than or equal to `3000`"
            )  # noqa: E501

        self._summary = summary

    @property
    def branding_theme_id(self):
        """Gets the branding_theme_id of this Quote.  # noqa: E501

        See BrandingThemes  # noqa: E501

        :return: The branding_theme_id of this Quote.  # noqa: E501
        :rtype: str
        """
        return self._branding_theme_id

    @branding_theme_id.setter
    def branding_theme_id(self, branding_theme_id):
        """Sets the branding_theme_id of this Quote.

        See BrandingThemes  # noqa: E501

        :param branding_theme_id: The branding_theme_id of this Quote.  # noqa: E501
        :type: str
        """

        self._branding_theme_id = branding_theme_id

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this Quote.  # noqa: E501

        Last modified date UTC format  # noqa: E501

        :return: The updated_date_utc of this Quote.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this Quote.

        Last modified date UTC format  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this Quote.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def line_amount_types(self):
        """Gets the line_amount_types of this Quote.  # noqa: E501


        :return: The line_amount_types of this Quote.  # noqa: E501
        :rtype: QuoteLineAmountTypes
        """
        return self._line_amount_types

    @line_amount_types.setter
    def line_amount_types(self, line_amount_types):
        """Sets the line_amount_types of this Quote.


        :param line_amount_types: The line_amount_types of this Quote.  # noqa: E501
        :type: QuoteLineAmountTypes
        """

        self._line_amount_types = line_amount_types

    @property
    def status_attribute_string(self):
        """Gets the status_attribute_string of this Quote.  # noqa: E501

        A string to indicate if a invoice status  # noqa: E501

        :return: The status_attribute_string of this Quote.  # noqa: E501
        :rtype: str
        """
        return self._status_attribute_string

    @status_attribute_string.setter
    def status_attribute_string(self, status_attribute_string):
        """Sets the status_attribute_string of this Quote.

        A string to indicate if a invoice status  # noqa: E501

        :param status_attribute_string: The status_attribute_string of this Quote.  # noqa: E501
        :type: str
        """

        self._status_attribute_string = status_attribute_string

    @property
    def validation_errors(self):
        """Gets the validation_errors of this Quote.  # noqa: E501

        Displays array of validation error messages from the API  # noqa: E501

        :return: The validation_errors of this Quote.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this Quote.

        Displays array of validation error messages from the API  # noqa: E501

        :param validation_errors: The validation_errors of this Quote.  # noqa: E501
        :type: list[ValidationError]
        """

        self._validation_errors = validation_errors



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class AccountsPayable(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"outstanding": "float", "overdue": "float"}

    attribute_map = {"outstanding": "Outstanding", "overdue": "Overdue"}

    def __init__(self, outstanding=None, overdue=None):  # noqa: E501
        """AccountsPayable - a model defined in OpenAPI"""  # noqa: E501

        self._outstanding = None
        self._overdue = None
        self.discriminator = None

        if outstanding is not None:
            self.outstanding = outstanding
        if overdue is not None:
            self.overdue = overdue

    @property
    def outstanding(self):
        """Gets the outstanding of this AccountsPayable.  # noqa: E501


        :return: The outstanding of this AccountsPayable.  # noqa: E501
        :rtype: float
        """
        return self._outstanding

    @outstanding.setter
    def outstanding(self, outstanding):
        """Sets the outstanding of this AccountsPayable.


        :param outstanding: The outstanding of this AccountsPayable.  # noqa: E501
        :type: float
        """

        self._outstanding = outstanding

    @property
    def overdue(self):
        """Gets the overdue of this AccountsPayable.  # noqa: E501


        :return: The overdue of this AccountsPayable.  # noqa: E501
        :rtype: float
        """
        return self._overdue

    @overdue.setter
    def overdue(self, overdue):
        """Sets the overdue of this AccountsPayable.


        :param overdue: The overdue of this AccountsPayable.  # noqa: E501
        :type: float
        """

        self._overdue = overdue



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class LeaveApplications(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"leave_applications": "list[LeaveApplication]"}

    attribute_map = {"leave_applications": "LeaveApplications"}

    def __init__(self, leave_applications=None):  # noqa: E501
        """LeaveApplications - a model defined in OpenAPI"""  # noqa: E501

        self._leave_applications = None
        self.discriminator = None

        if leave_applications is not None:
            self.leave_applications = leave_applications

    @property
    def leave_applications(self):
        """Gets the leave_applications of this LeaveApplications.  # noqa: E501


        :return: The leave_applications of this LeaveApplications.  # noqa: E501
        :rtype: list[LeaveApplication]
        """
        return self._leave_applications

    @leave_applications.setter
    def leave_applications(self, leave_applications):
        """Sets the leave_applications of this LeaveApplications.


        :param leave_applications: The leave_applications of this LeaveApplications.  # noqa: E501
        :type: list[LeaveApplication]
        """

        self._leave_applications = leave_applications



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class TaxComponent(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "name": "str",
        "rate": "float",
        "is_compound": "bool",
        "is_non_recoverable": "bool",
    }

    attribute_map = {
        "name": "Name",
        "rate": "Rate",
        "is_compound": "IsCompound",
        "is_non_recoverable": "IsNonRecoverable",
    }

    def __init__(
        self, name=None, rate=None, is_compound=None, is_non_recoverable=None
    ):  # noqa: E501
        """TaxComponent - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._rate = None
        self._is_compound = None
        self._is_non_recoverable = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if rate is not None:
            self.rate = rate
        if is_compound is not None:
            self.is_compound = is_compound
        if is_non_recoverable is not None:
            self.is_non_recoverable = is_non_recoverable

    @property
    def name(self):
        """Gets the name of this TaxComponent.  # noqa: E501

        Name of Tax Component  # noqa: E501

        :return: The name of this TaxComponent.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TaxComponent.

        Name of Tax Component  # noqa: E501

        :param name: The name of this TaxComponent.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def rate(self):
        """Gets the rate of this TaxComponent.  # noqa: E501

        Tax Rate (up to 4dp)  # noqa: E501

        :return: The rate of this TaxComponent.  # noqa: E501
        :rtype: float
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        """Sets the rate of this TaxComponent.

        Tax Rate (up to 4dp)  # noqa: E501

        :param rate: The rate of this TaxComponent.  # noqa: E501
        :type: float
        """

        self._rate = rate

    @property
    def is_compound(self):
        """Gets the is_compound of this TaxComponent.  # noqa: E501

        Boolean to describe if Tax rate is compounded.  # noqa: E501

        :return: The is_compound of this TaxComponent.  # noqa: E501
        :rtype: bool
        """
        return self._is_compound

    @is_compound.setter
    def is_compound(self, is_compound):
        """Sets the is_compound of this TaxComponent.

        Boolean to describe if Tax rate is compounded.  # noqa: E501

        :param is_compound: The is_compound of this TaxComponent.  # noqa: E501
        :type: bool
        """

        self._is_compound = is_compound

    @property
    def is_non_recoverable(self):
        """Gets the is_non_recoverable of this TaxComponent.  # noqa: E501

        Boolean to describe if tax rate is non-recoverable. Non-recoverable rates are only applicable to Canadian organisations  # noqa: E501

        :return: The is_non_recoverable of this TaxComponent.  # noqa: E501
        :rtype: bool
        """
        return self._is_non_recoverable

    @is_non_recoverable.setter
    def is_non_recoverable(self, is_non_recoverable):
        """Sets the is_non_recoverable of this TaxComponent.

        Boolean to describe if tax rate is non-recoverable. Non-recoverable rates are only applicable to Canadian organisations  # noqa: E501

        :param is_non_recoverable: The is_non_recoverable of this TaxComponent.  # noqa: E501
        :type: bool
        """

        self._is_non_recoverable = is_non_recoverable
